@@ -10,16 +10,21 @@ insDoc(aux1, gLnk("R", "ABCapHeight", "vars/Time-Dependent.html#ABCapHeight"))
 insDoc(aux1, gLnk("R", "ABShape", "vars/Time-Dependent.html#ABShape"))
 insDoc(aux1, gLnk("R", "AbsorbingBoundaries", "vars/Time-Dependent.html#AbsorbingBoundaries"))
 insDoc(aux1, gLnk("R", "ABWidth", "vars/Time-Dependent.html#ABWidth"))
+insDoc(aux1, gLnk("R", "ACBN0IntersiteCutoff", "vars/Hamiltonian.html#ACBN0IntersiteCutoff"))
+insDoc(aux1, gLnk("R", "ACBN0IntersiteInteraction", "vars/Hamiltonian.html#ACBN0IntersiteInteraction"))
 insDoc(aux1, gLnk("R", "ACBN0RotationallyInvariant", "vars/Hamiltonian.html#ACBN0RotationallyInvariant"))
 insDoc(aux1, gLnk("R", "ACBN0Screening", "vars/Hamiltonian.html#ACBN0Screening"))
+insDoc(aux1, gLnk("R", "AccelBenchmark", "vars/Execution.html#AccelBenchmark"))
+insDoc(aux1, gLnk("R", "AccelDevice", "vars/Execution.html#AccelDevice"))
+insDoc(aux1, gLnk("R", "AccelPlatform", "vars/Execution.html#AccelPlatform"))
 insDoc(aux1, gLnk("R", "AlphaFMM", "vars/Hamiltonian.html#AlphaFMM"))
 insDoc(aux1, gLnk("R", "AnimationMultiFiles", "vars/Utilities.html#AnimationMultiFiles"))
 insDoc(aux1, gLnk("R", "AnimationSampling", "vars/Utilities.html#AnimationSampling"))
-insDoc(aux1, gLnk("R", "AOLoewdin", "vars/Hamiltonian.html#AOLoewdin"))
-insDoc(aux1, gLnk("R", "AONormalize", "vars/Hamiltonian.html#AONormalize"))
-insDoc(aux1, gLnk("R", "AOSubmeshForPeriodic", "vars/Hamiltonian.html#AOSubmeshForPeriodic"))
-insDoc(aux1, gLnk("R", "AOThreshold", "vars/Hamiltonian.html#AOThreshold"))
-insDoc(aux1, gLnk("R", "AOTruncation", "vars/Hamiltonian.html#AOTruncation"))
+insDoc(aux1, gLnk("R", "AOLoewdin", "vars/Atomic_Orbitals.html#AOLoewdin"))
+insDoc(aux1, gLnk("R", "AONormalize", "vars/Atomic_Orbitals.html#AONormalize"))
+insDoc(aux1, gLnk("R", "AOSubmeshForPeriodic", "vars/Atomic_Orbitals.html#AOSubmeshForPeriodic"))
+insDoc(aux1, gLnk("R", "AOThreshold", "vars/Atomic_Orbitals.html#AOThreshold"))
+insDoc(aux1, gLnk("R", "AOTruncation", "vars/Atomic_Orbitals.html#AOTruncation"))
 insDoc(aux1, gLnk("R", "ArnoldiOrthogonalization", "vars/Time-Dependent.html#ArnoldiOrthogonalization"))
 insDoc(aux1, gLnk("R", "AtomsMagnetDirection", "vars/SCF.html#AtomsMagnetDirection"))
 insDoc(aux1, gLnk("R", "AxisType", "vars/Utilities.html#AxisType"))
@@ -66,7 +71,12 @@ insDoc(aux1, gLnk("R", "CasidaTransitionDensities", "vars/Linear_Response.html#C
 insDoc(aux1, gLnk("R", "CasidaWeightThreshold", "vars/Linear_Response.html#CasidaWeightThreshold"))
 insDoc(aux1, gLnk("R", "CGAdditionalTerms", "vars/SCF.html#CGAdditionalTerms"))
 insDoc(aux1, gLnk("R", "CGDirection", "vars/SCF.html#CGDirection"))
+insDoc(aux1, gLnk("R", "CGEnergyChangeThreshold", "vars/SCF.html#CGEnergyChangeThreshold"))
 insDoc(aux1, gLnk("R", "CGOrthogonalizeAll", "vars/SCF.html#CGOrthogonalizeAll"))
+insDoc(aux1, gLnk("R", "ClassicalParticleCharge", "vars/ClassicalParticles.html#ClassicalParticleCharge"))
+insDoc(aux1, gLnk("R", "ClassicalParticleInitialPosition", "vars/ClassicalParticles.html#ClassicalParticleInitialPosition"))
+insDoc(aux1, gLnk("R", "ClassicalParticleInitialVelocity", "vars/ClassicalParticles.html#ClassicalParticleInitialVelocity"))
+insDoc(aux1, gLnk("R", "ClassicalParticleMass", "vars/ClassicalParticles.html#ClassicalParticleMass"))
 insDoc(aux1, gLnk("R", "ClassicalPotential", "vars/Hamiltonian.html#ClassicalPotential"))
 insDoc(aux1, gLnk("R", "ConductivityFromForces", "vars/Utilities.html#ConductivityFromForces"))
 insDoc(aux1, gLnk("R", "ConductivitySpectrumTimeStepFactor", "vars/Utilities.html#ConductivitySpectrumTimeStepFactor"))
@@ -96,6 +106,7 @@ insDoc(aux1, gLnk("R", "ConvForce", "vars/SCF.html#ConvForce"))
 insDoc(aux1, gLnk("R", "ConvRelDens", "vars/SCF.html#ConvRelDens"))
 insDoc(aux1, gLnk("R", "ConvRelEv", "vars/SCF.html#ConvRelEv"))
 insDoc(aux1, gLnk("R", "Coordinates", "vars/System.html#Coordinates"))
+insDoc(aux1, gLnk("R", "CudaAwareMPI", "vars/Execution.html#CudaAwareMPI"))
 insDoc(aux1, gLnk("R", "CurrentDensity", "vars/Hamiltonian.html#CurrentDensity"))
 insDoc(aux1, gLnk("R", "CurrentThroughPlane", "vars/Output.html#CurrentThroughPlane"))
 insDoc(aux1, gLnk("R", "CurvGygiA", "vars/Mesh.html#CurvGygiA"))
@@ -119,6 +130,7 @@ insDoc(aux1, gLnk("R", "DFTUBasisFromStates", "vars/Hamiltonian.html#DFTUBasisFr
 insDoc(aux1, gLnk("R", "DFTUBasisStates", "vars/Hamiltonian.html#DFTUBasisStates"))
 insDoc(aux1, gLnk("R", "DFTUDoubleCounting", "vars/Hamiltonian.html#DFTUDoubleCounting"))
 insDoc(aux1, gLnk("R", "DFTULevel", "vars/Hamiltonian.html#DFTULevel"))
+insDoc(aux1, gLnk("R", "DFTUPoissonSolver", "vars/Hamiltonian.html#DFTUPoissonSolver"))
 insDoc(aux1, gLnk("R", "Dimensions", "vars/System.html#Dimensions"))
 insDoc(aux1, gLnk("R", "DisableAccel", "vars/Execution.html#DisableAccel"))
 insDoc(aux1, gLnk("R", "Displacement", "vars/Linear_Response.html#Displacement"))
@@ -130,6 +142,7 @@ insDoc(aux1, gLnk("R", "DOSGamma", "vars/Output.html#DOSGamma"))
 insDoc(aux1, gLnk("R", "DoubleFFTParameter", "vars/Mesh.html#DoubleFFTParameter"))
 insDoc(aux1, gLnk("R", "DoubleGrid", "vars/Mesh.html#DoubleGrid"))
 insDoc(aux1, gLnk("R", "DoubleGridOrder", "vars/Mesh.html#DoubleGridOrder"))
+insDoc(aux1, gLnk("R", "DressedOrbitals", "vars/Hamiltonian.html#DressedOrbitals"))
 aux1 = insFld(aux0, gFld("E", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "Eigensolver", "vars/SCF.html#Eigensolver"))
 insDoc(aux1, gLnk("R", "EigensolverImaginaryTime", "vars/SCF.html#EigensolverImaginaryTime"))
@@ -159,6 +172,7 @@ insDoc(aux1, gLnk("R", "EMWriteRestartDensities", "vars/Linear_Response.html#EMW
 insDoc(aux1, gLnk("R", "EwaldAlpha", "vars/Hamiltonian.html#EwaldAlpha"))
 insDoc(aux1, gLnk("R", "ExcessCharge", "vars/States.html#ExcessCharge"))
 insDoc(aux1, gLnk("R", "ExperimentalFeatures", "vars/Execution.html#ExperimentalFeatures"))
+insDoc(aux1, gLnk("R", "ExternalCurrent", "vars/Hamiltonian.html#ExternalCurrent"))
 insDoc(aux1, gLnk("R", "ExtraStates", "vars/States.html#ExtraStates"))
 insDoc(aux1, gLnk("R", "ExtraStatesToConverge", "vars/States.html#ExtraStatesToConverge"))
 aux1 = insFld(aux0, gFld("F", "javascript:parent.op()"))
@@ -191,6 +205,9 @@ insDoc(aux1, gLnk("R", "GyromagneticRatio", "vars/Hamiltonian.html#GyromagneticR
 aux1 = insFld(aux0, gFld("H", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "HamiltonianApplyPacked", "vars/Execution.html#HamiltonianApplyPacked"))
 insDoc(aux1, gLnk("R", "HamiltonianVariation", "vars/Linear_Response.html#HamiltonianVariation"))
+insDoc(aux1, gLnk("R", "HFSingularity", "vars/Hamiltonian.html#HFSingularity"))
+insDoc(aux1, gLnk("R", "HFSingularityNk", "vars/Hamiltonian.html#HFSingularityNk"))
+insDoc(aux1, gLnk("R", "HFSingularityNsteps", "vars/Hamiltonian.html#HFSingularityNsteps"))
 aux1 = insFld(aux0, gFld("I", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "IgnoreExternalIons", "vars/Hamiltonian.html#IgnoreExternalIons"))
 insDoc(aux1, gLnk("R", "InitialSpins", "vars/States.html#InitialSpins"))
@@ -214,6 +231,7 @@ insDoc(aux1, gLnk("R", "KdotPEta", "vars/Linear_Response.html#KdotPEta"))
 insDoc(aux1, gLnk("R", "KdotPOccupiedSolutionMethod", "vars/Linear_Response.html#KdotPOccupiedSolutionMethod"))
 insDoc(aux1, gLnk("R", "KdotPUseNonLocalPseudopotential", "vars/Linear_Response.html#KdotPUseNonLocalPseudopotential"))
 insDoc(aux1, gLnk("R", "KdotPVelMethod", "vars/Linear_Response.html#KdotPVelMethod"))
+insDoc(aux1, gLnk("R", "KLIPhotonCOC", "vars/Hamiltonian.html#KLIPhotonCOC"))
 insDoc(aux1, gLnk("R", "KPoints", "vars/Mesh.html#KPoints"))
 insDoc(aux1, gLnk("R", "KPointsGrid", "vars/Mesh.html#KPointsGrid"))
 insDoc(aux1, gLnk("R", "KPointsPath", "vars/Mesh.html#KPointsPath"))
@@ -225,8 +243,6 @@ insDoc(aux1, gLnk("R", "KSInversionLevel", "vars/Calculation_Modes.html#KSInvers
 aux1 = insFld(aux0, gFld("L", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "LatticeParameters", "vars/Mesh.html#LatticeParameters"))
 insDoc(aux1, gLnk("R", "LatticeVectors", "vars/Mesh.html#LatticeVectors"))
-insDoc(aux1, gLnk("R", "LB94_modified", "vars/Hamiltonian.html#LB94_modified"))
-insDoc(aux1, gLnk("R", "LB94_threshold", "vars/Hamiltonian.html#LB94_threshold"))
 insDoc(aux1, gLnk("R", "LCAOAlternative", "vars/SCF.html#LCAOAlternative"))
 insDoc(aux1, gLnk("R", "LCAOComplexYlms", "vars/SCF.html#LCAOComplexYlms"))
 insDoc(aux1, gLnk("R", "LCAODiagTol", "vars/SCF.html#LCAODiagTol"))
@@ -276,6 +292,32 @@ insDoc(aux1, gLnk("R", "MainAxis", "vars/Utilities.html#MainAxis"))
 insDoc(aux1, gLnk("R", "MassScaling", "vars/Hamiltonian.html#MassScaling"))
 insDoc(aux1, gLnk("R", "MaximumIter", "vars/SCF.html#MaximumIter"))
 insDoc(aux1, gLnk("R", "MaximumIterBerry", "vars/SCF.html#MaximumIterBerry"))
+insDoc(aux1, gLnk("R", "MaxwellABPMLPower", "vars/Time-Dependent.html#MaxwellABPMLPower"))
+insDoc(aux1, gLnk("R", "MaxwellABPMLReflectionError", "vars/Time-Dependent.html#MaxwellABPMLReflectionError"))
+insDoc(aux1, gLnk("R", "MaxwellAbsorbingBoundaries", "vars/Time-Dependent.html#MaxwellAbsorbingBoundaries"))
+insDoc(aux1, gLnk("R", "MaxwellABWidth", "vars/Time-Dependent.html#MaxwellABWidth"))
+insDoc(aux1, gLnk("R", "MaxwellBoundaryConditions", "vars/Time-Dependent.html#MaxwellBoundaryConditions"))
+insDoc(aux1, gLnk("R", "MaxwellFieldsCoordinate", "vars/System.html#MaxwellFieldsCoordinate"))
+insDoc(aux1, gLnk("R", "MaxwellFunctions", "vars/Time-Dependent.html#MaxwellFunctions"))
+insDoc(aux1, gLnk("R", "MaxwellHamiltonianOperator", "vars/Hamiltonian.html#MaxwellHamiltonianOperator"))
+insDoc(aux1, gLnk("R", "MaxwellIncidentWaves", "vars/MaxwellStates.html#MaxwellIncidentWaves"))
+insDoc(aux1, gLnk("R", "MaxwellMediumBox", "vars/Time-Dependent.html#MaxwellMediumBox"))
+insDoc(aux1, gLnk("R", "MaxwellMediumCalculation", "vars/Hamiltonian.html#MaxwellMediumCalculation"))
+insDoc(aux1, gLnk("R", "MaxwellOutput", "vars/Output.html#MaxwellOutput"))
+insDoc(aux1, gLnk("R", "MaxwellOutputInterval", "vars/Output.html#MaxwellOutputInterval"))
+insDoc(aux1, gLnk("R", "MaxwellOutputIterDir", "vars/Output.html#MaxwellOutputIterDir"))
+insDoc(aux1, gLnk("R", "MaxwellPlaneWavesInBox", "vars/States.html#MaxwellPlaneWavesInBox"))
+insDoc(aux1, gLnk("R", "MaxwellRestartWriteInterval", "vars/Execution.html#MaxwellRestartWriteInterval"))
+insDoc(aux1, gLnk("R", "MaxwellTDETRSApprox", "vars/Time-Dependent.html#MaxwellTDETRSApprox"))
+insDoc(aux1, gLnk("R", "MaxwellTDIntervalSteps", "vars/Time-Dependent.html#MaxwellTDIntervalSteps"))
+insDoc(aux1, gLnk("R", "MaxwellTDOperatorMethod", "vars/Time-Dependent.html#MaxwellTDOperatorMethod"))
+insDoc(aux1, gLnk("R", "MaxwellTDOutput", "vars/Time-Dependent.html#MaxwellTDOutput"))
+insDoc(aux1, gLnk("R", "MaxwellTDSCFThreshold", "vars/Time-Dependent.html#MaxwellTDSCFThreshold"))
+insDoc(aux1, gLnk("R", "MediumElectricSigma", "vars/Time-Dependent.html#MediumElectricSigma"))
+insDoc(aux1, gLnk("R", "MediumEpsilonFactor", "vars/Time-Dependent.html#MediumEpsilonFactor"))
+insDoc(aux1, gLnk("R", "MediumMagneticSigma", "vars/Time-Dependent.html#MediumMagneticSigma"))
+insDoc(aux1, gLnk("R", "MediumMuFactor", "vars/Time-Dependent.html#MediumMuFactor"))
+insDoc(aux1, gLnk("R", "MediumWidth", "vars/Time-Dependent.html#MediumWidth"))
 insDoc(aux1, gLnk("R", "MemoryLimit", "vars/Execution.html#MemoryLimit"))
 insDoc(aux1, gLnk("R", "MeshBlockSize", "vars/Execution.html#MeshBlockSize"))
 insDoc(aux1, gLnk("R", "MeshOrder", "vars/Execution.html#MeshOrder"))
@@ -353,14 +395,12 @@ insDoc(aux1, gLnk("R", "OCTVelocityDerivatives", "vars/Calculation_Modes.html#OC
 insDoc(aux1, gLnk("R", "OCTVelocityTarget", "vars/Calculation_Modes.html#OCTVelocityTarget"))
 insDoc(aux1, gLnk("R", "OEPLevel", "vars/Hamiltonian.html#OEPLevel"))
 insDoc(aux1, gLnk("R", "OEPMixing", "vars/Hamiltonian.html#OEPMixing"))
+insDoc(aux1, gLnk("R", "OEPMixingScheme", "vars/Hamiltonian.html#OEPMixingScheme"))
 insDoc(aux1, gLnk("R", "OnlyUserDefinedInitialStates", "vars/States.html#OnlyUserDefinedInitialStates"))
-insDoc(aux1, gLnk("R", "OpenCLBenchmark", "vars/Execution.html#OpenCLBenchmark"))
-insDoc(aux1, gLnk("R", "OpenCLDevice", "vars/Execution.html#OpenCLDevice"))
-insDoc(aux1, gLnk("R", "OpenCLPlatform", "vars/Execution.html#OpenCLPlatform"))
+insDoc(aux1, gLnk("R", "OperateAccel", "vars/Execution.html#OperateAccel"))
 insDoc(aux1, gLnk("R", "OperateComplex", "vars/Execution.html#OperateComplex"))
 insDoc(aux1, gLnk("R", "OperateComplexSingle", "vars/Execution.html#OperateComplexSingle"))
 insDoc(aux1, gLnk("R", "OperateDouble", "vars/Execution.html#OperateDouble"))
-insDoc(aux1, gLnk("R", "OperateOpenCL", "vars/Execution.html#OperateOpenCL"))
 insDoc(aux1, gLnk("R", "OperateSingle", "vars/Execution.html#OperateSingle"))
 insDoc(aux1, gLnk("R", "Output", "vars/Output.html#Output"))
 insDoc(aux1, gLnk("R", "Output_KPT", "vars/Output.html#Output_KPT"))
@@ -370,7 +410,9 @@ insDoc(aux1, gLnk("R", "OutputInterval", "vars/Output.html#OutputInterval"))
 insDoc(aux1, gLnk("R", "OutputIterDir", "vars/Output.html#OutputIterDir"))
 insDoc(aux1, gLnk("R", "OutputLDA_U", "vars/Output.html#OutputLDA_U"))
 insDoc(aux1, gLnk("R", "OutputMatrixElements", "vars/Output.html#OutputMatrixElements"))
+insDoc(aux1, gLnk("R", "OutputMEEnd", "vars/Output.html#OutputMEEnd"))
 insDoc(aux1, gLnk("R", "OutputMEMultipoles", "vars/Output.html#OutputMEMultipoles"))
+insDoc(aux1, gLnk("R", "OutputMEStart", "vars/Output.html#OutputMEStart"))
 insDoc(aux1, gLnk("R", "OutputWfsNumber", "vars/Output.html#OutputWfsNumber"))
 aux1 = insFld(aux0, gFld("P", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "ParallelizationNumberSlaves", "vars/Execution.html#ParallelizationNumberSlaves"))
@@ -391,13 +433,11 @@ insDoc(aux1, gLnk("R", "PCMDebyeRelaxTime", "vars/Hamiltonian.html#PCMDebyeRelax
 insDoc(aux1, gLnk("R", "PCMDrudeLDamping", "vars/Hamiltonian.html#PCMDrudeLDamping"))
 insDoc(aux1, gLnk("R", "PCMDrudeLOmega", "vars/Hamiltonian.html#PCMDrudeLOmega"))
 insDoc(aux1, gLnk("R", "PCMDynamicEpsilon", "vars/Hamiltonian.html#PCMDynamicEpsilon"))
-insDoc(aux1, gLnk("R", "PCMEoM", "vars/Hamiltonian.html#PCMEoM"))
 insDoc(aux1, gLnk("R", "PCMEoMInitialCharges", "vars/Hamiltonian.html#PCMEoMInitialCharges"))
 insDoc(aux1, gLnk("R", "PCMEpsilonModel", "vars/Hamiltonian.html#PCMEpsilonModel"))
 insDoc(aux1, gLnk("R", "PCMGamessBenchmark", "vars/Hamiltonian.html#PCMGamessBenchmark"))
 insDoc(aux1, gLnk("R", "PCMKick", "vars/Hamiltonian.html#PCMKick"))
 insDoc(aux1, gLnk("R", "PCMLocalField", "vars/Hamiltonian.html#PCMLocalField"))
-insDoc(aux1, gLnk("R", "PCMNonequilibrium", "vars/Hamiltonian.html#PCMNonequilibrium"))
 insDoc(aux1, gLnk("R", "PCMQtotTol", "vars/Hamiltonian.html#PCMQtotTol"))
 insDoc(aux1, gLnk("R", "PCMRadiusScaling", "vars/Hamiltonian.html#PCMRadiusScaling"))
 insDoc(aux1, gLnk("R", "PCMRenormCharges", "vars/Hamiltonian.html#PCMRenormCharges"))
@@ -405,6 +445,7 @@ insDoc(aux1, gLnk("R", "PCMSmearingFactor", "vars/Hamiltonian.html#PCMSmearingFa
 insDoc(aux1, gLnk("R", "PCMSolute", "vars/Hamiltonian.html#PCMSolute"))
 insDoc(aux1, gLnk("R", "PCMSpheresOnH", "vars/Hamiltonian.html#PCMSpheresOnH"))
 insDoc(aux1, gLnk("R", "PCMStaticEpsilon", "vars/Hamiltonian.html#PCMStaticEpsilon"))
+insDoc(aux1, gLnk("R", "PCMTDLevel", "vars/Hamiltonian.html#PCMTDLevel"))
 insDoc(aux1, gLnk("R", "PCMTessMinDistance", "vars/Hamiltonian.html#PCMTessMinDistance"))
 insDoc(aux1, gLnk("R", "PCMTessSubdivider", "vars/Hamiltonian.html#PCMTessSubdivider"))
 insDoc(aux1, gLnk("R", "PCMUpdateIter", "vars/Hamiltonian.html#PCMUpdateIter"))
@@ -413,6 +454,7 @@ insDoc(aux1, gLnk("R", "PDBClassical", "vars/System.html#PDBClassical"))
 insDoc(aux1, gLnk("R", "PDBCoordinates", "vars/System.html#PDBCoordinates"))
 insDoc(aux1, gLnk("R", "PDBGOConstrains", "vars/Calculation_Modes.html#PDBGOConstrains"))
 insDoc(aux1, gLnk("R", "PDBVelocities", "vars/System.html#PDBVelocities"))
+insDoc(aux1, gLnk("R", "PeriodicBoundaryMask", "vars/Mesh.html#PeriodicBoundaryMask"))
 insDoc(aux1, gLnk("R", "PeriodicDimensions", "vars/System.html#PeriodicDimensions"))
 insDoc(aux1, gLnk("R", "PES_Flux_ARPES_grid", "vars/Time-Dependent.html#PES_Flux_ARPES_grid"))
 insDoc(aux1, gLnk("R", "PES_Flux_AvoidAB", "vars/Time-Dependent.html#PES_Flux_AvoidAB"))
@@ -452,6 +494,8 @@ insDoc(aux1, gLnk("R", "PESMaskStartTime", "vars/Time-Dependent.html#PESMaskStar
 insDoc(aux1, gLnk("R", "PhotoElectronSpectrum", "vars/Time-Dependent.html#PhotoElectronSpectrum"))
 insDoc(aux1, gLnk("R", "PhotoelectronSpectrumOutput", "vars/Utilities.html#PhotoelectronSpectrumOutput"))
 insDoc(aux1, gLnk("R", "PhotoelectronSpectrumResolveStates", "vars/Utilities.html#PhotoelectronSpectrumResolveStates"))
+insDoc(aux1, gLnk("R", "PhotonModes", "vars/Hamiltonian.html#PhotonModes"))
+insDoc(aux1, gLnk("R", "Photons", "vars/Hamiltonian.html#Photons"))
 insDoc(aux1, gLnk("R", "PNFFTCutoff", "vars/Mesh.html#PNFFTCutoff"))
 insDoc(aux1, gLnk("R", "PNFFTOversampling", "vars/Mesh.html#PNFFTOversampling"))
 insDoc(aux1, gLnk("R", "Poisson1DSoftCoulombParam", "vars/Hamiltonian.html#Poisson1DSoftCoulombParam"))
@@ -459,7 +503,6 @@ insDoc(aux1, gLnk("R", "PoissonCutoffRadius", "vars/Hamiltonian.html#PoissonCuto
 insDoc(aux1, gLnk("R", "PoissonFFTKernel", "vars/Hamiltonian.html#PoissonFFTKernel"))
 insDoc(aux1, gLnk("R", "PoissonSolver", "vars/Hamiltonian.html#PoissonSolver"))
 insDoc(aux1, gLnk("R", "PoissonSolverBoundaries", "vars/Hamiltonian.html#PoissonSolverBoundaries"))
-insDoc(aux1, gLnk("R", "PoissonSolverISFParallelData", "vars/Hamiltonian.html#PoissonSolverISFParallelData"))
 insDoc(aux1, gLnk("R", "PoissonSolverMaxIter", "vars/Hamiltonian.html#PoissonSolverMaxIter"))
 insDoc(aux1, gLnk("R", "PoissonSolverMaxMultipole", "vars/Hamiltonian.html#PoissonSolverMaxMultipole"))
 insDoc(aux1, gLnk("R", "PoissonSolverMGMaxCycles", "vars/Hamiltonian.html#PoissonSolverMGMaxCycles"))
@@ -469,6 +512,7 @@ insDoc(aux1, gLnk("R", "PoissonSolverMGRelaxationFactor", "vars/Hamiltonian.html
 insDoc(aux1, gLnk("R", "PoissonSolverMGRelaxationMethod", "vars/Hamiltonian.html#PoissonSolverMGRelaxationMethod"))
 insDoc(aux1, gLnk("R", "PoissonSolverMGRestrictionMethod", "vars/Hamiltonian.html#PoissonSolverMGRestrictionMethod"))
 insDoc(aux1, gLnk("R", "PoissonSolverNodes", "vars/Hamiltonian.html#PoissonSolverNodes"))
+insDoc(aux1, gLnk("R", "PoissonSolverPSolverParallelData", "vars/Hamiltonian.html#PoissonSolverPSolverParallelData"))
 insDoc(aux1, gLnk("R", "PoissonSolverThreshold", "vars/Hamiltonian.html#PoissonSolverThreshold"))
 insDoc(aux1, gLnk("R", "Preconditioner", "vars/SCF.html#Preconditioner"))
 insDoc(aux1, gLnk("R", "PreconditionerFilterFactor", "vars/SCF.html#PreconditionerFilterFactor"))
@@ -478,11 +522,13 @@ insDoc(aux1, gLnk("R", "PreconditionerIterationsPre", "vars/SCF.html#Preconditio
 insDoc(aux1, gLnk("R", "Preorthogonalization", "vars/Linear_Response.html#Preorthogonalization"))
 insDoc(aux1, gLnk("R", "ProfilingAllNodes", "vars/Execution.html#ProfilingAllNodes"))
 insDoc(aux1, gLnk("R", "ProfilingMode", "vars/Execution.html#ProfilingMode"))
+insDoc(aux1, gLnk("R", "ProfilingOutputYAML", "vars/Execution.html#ProfilingOutputYAML"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumDampFactor", "vars/Utilities.html#PropagationSpectrumDampFactor"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumDampMode", "vars/Utilities.html#PropagationSpectrumDampMode"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumEndTime", "vars/Utilities.html#PropagationSpectrumEndTime"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumEnergyStep", "vars/Utilities.html#PropagationSpectrumEnergyStep"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumMaxEnergy", "vars/Utilities.html#PropagationSpectrumMaxEnergy"))
+insDoc(aux1, gLnk("R", "PropagationSpectrumMinEnergy", "vars/Utilities.html#PropagationSpectrumMinEnergy"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumSigmaDiagonalization", "vars/Utilities.html#PropagationSpectrumSigmaDiagonalization"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumStartTime", "vars/Utilities.html#PropagationSpectrumStartTime"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumSymmetrizeSigma", "vars/Utilities.html#PropagationSpectrumSymmetrizeSigma"))
@@ -491,16 +537,21 @@ insDoc(aux1, gLnk("R", "PropagationSpectrumType", "vars/Utilities.html#Propagati
 insDoc(aux1, gLnk("R", "PseudopotentialAutomaticParameters", "vars/System.html#PseudopotentialAutomaticParameters"))
 insDoc(aux1, gLnk("R", "PseudopotentialEnergyTolerance", "vars/System.html#PseudopotentialEnergyTolerance"))
 insDoc(aux1, gLnk("R", "PseudopotentialSet", "vars/System.html#PseudopotentialSet"))
+aux1 = insFld(aux0, gFld("Q", "javascript:parent.op()"))
+insDoc(aux1, gLnk("R", "QPointsGrid", "vars/Mesh.html#QPointsGrid"))
 aux1 = insFld(aux0, gFld("R", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "Radius", "vars/Mesh.html#Radius"))
 insDoc(aux1, gLnk("R", "RandomVelocityTemp", "vars/System.html#RandomVelocityTemp"))
 insDoc(aux1, gLnk("R", "RashbaSpinOrbitCoupling", "vars/Hamiltonian.html#RashbaSpinOrbitCoupling"))
 insDoc(aux1, gLnk("R", "RDMBasis", "vars/SCF.html#RDMBasis"))
 insDoc(aux1, gLnk("R", "RDMConvEner", "vars/SCF.html#RDMConvEner"))
+insDoc(aux1, gLnk("R", "RDMHartreeFock", "vars/SCF.html#RDMHartreeFock"))
 insDoc(aux1, gLnk("R", "RDMTolerance", "vars/SCF.html#RDMTolerance"))
+insDoc(aux1, gLnk("R", "RDMToleranceFO", "vars/SCF.html#RDMToleranceFO"))
 insDoc(aux1, gLnk("R", "RecalculateGSDuringEvolution", "vars/Time-Dependent.html#RecalculateGSDuringEvolution"))
 insDoc(aux1, gLnk("R", "ReducedCoordinates", "vars/System.html#ReducedCoordinates"))
 insDoc(aux1, gLnk("R", "RelativisticCorrection", "vars/Hamiltonian.html#RelativisticCorrection"))
+insDoc(aux1, gLnk("R", "ReorderRanks", "vars/Execution.html#ReorderRanks"))
 insDoc(aux1, gLnk("R", "ReportMemory", "vars/Execution.html#ReportMemory"))
 insDoc(aux1, gLnk("R", "ResponseMethod", "vars/Linear_Response.html#ResponseMethod"))
 insDoc(aux1, gLnk("R", "RestartFixedOccupations", "vars/States.html#RestartFixedOccupations"))
@@ -508,6 +559,8 @@ insDoc(aux1, gLnk("R", "RestartOptions", "vars/Execution.html#RestartOptions"))
 insDoc(aux1, gLnk("R", "RestartReorderOccs", "vars/States.html#RestartReorderOccs"))
 insDoc(aux1, gLnk("R", "RestartWrite", "vars/Execution.html#RestartWrite"))
 insDoc(aux1, gLnk("R", "RestartWriteInterval", "vars/Execution.html#RestartWriteInterval"))
+insDoc(aux1, gLnk("R", "RestartWriteTime", "vars/Execution.html#RestartWriteTime"))
+insDoc(aux1, gLnk("R", "RiemannSilbersteinSign", "vars/Hamiltonian.html#RiemannSilbersteinSign"))
 insDoc(aux1, gLnk("R", "RootSolver", "vars/Math.html#RootSolver"))
 insDoc(aux1, gLnk("R", "RootSolverAbsTolerance", "vars/Math.html#RootSolverAbsTolerance"))
 insDoc(aux1, gLnk("R", "RootSolverHavePolynomial", "vars/Math.html#RootSolverHavePolynomial"))
@@ -519,6 +572,8 @@ insDoc(aux1, gLnk("R", "ScaLAPACKCompatible", "vars/Execution.html#ScaLAPACKComp
 insDoc(aux1, gLnk("R", "SCDM_EXX", "vars/Hamiltonian.html#SCDM_EXX"))
 insDoc(aux1, gLnk("R", "SCDM_verbose", "vars/Hamiltonian.html#SCDM_verbose"))
 insDoc(aux1, gLnk("R", "SCDMCutoffRadius", "vars/Hamiltonian.html#SCDMCutoffRadius"))
+insDoc(aux1, gLnk("R", "SCDMmu", "vars/Utilities.html#SCDMmu"))
+insDoc(aux1, gLnk("R", "SCDMsigma", "vars/Utilities.html#SCDMsigma"))
 insDoc(aux1, gLnk("R", "SCFCalculateDipole", "vars/SCF.html#SCFCalculateDipole"))
 insDoc(aux1, gLnk("R", "SCFCalculateForces", "vars/SCF.html#SCFCalculateForces"))
 insDoc(aux1, gLnk("R", "SCFCalculatePartialCharges", "vars/SCF.html#SCFCalculatePartialCharges"))
@@ -544,10 +599,9 @@ insDoc(aux1, gLnk("R", "SpeciesTimeDependent", "vars/System.html#SpeciesTimeDepe
 insDoc(aux1, gLnk("R", "SpectrumMethod", "vars/Utilities.html#SpectrumMethod"))
 insDoc(aux1, gLnk("R", "SpectrumSignalNoise", "vars/Utilities.html#SpectrumSignalNoise"))
 insDoc(aux1, gLnk("R", "SpinComponents", "vars/States.html#SpinComponents"))
-insDoc(aux1, gLnk("R", "Splines", "vars/Execution.html#Splines"))
+insDoc(aux1, gLnk("R", "SpiralBoundaryCondition", "vars/Mesh.html#SpiralBoundaryCondition"))
 insDoc(aux1, gLnk("R", "StatesBlockSize", "vars/Execution.html#StatesBlockSize"))
 insDoc(aux1, gLnk("R", "StatesCLDeviceMemory", "vars/Execution.html#StatesCLDeviceMemory"))
-insDoc(aux1, gLnk("R", "StatesMirror", "vars/Execution.html#StatesMirror"))
 insDoc(aux1, gLnk("R", "StatesOrthogonalization", "vars/SCF.html#StatesOrthogonalization"))
 insDoc(aux1, gLnk("R", "StatesPack", "vars/Execution.html#StatesPack"))
 insDoc(aux1, gLnk("R", "StatesRandomization", "vars/States.html#StatesRandomization"))
@@ -561,12 +615,14 @@ insDoc(aux1, gLnk("R", "SymmetriesCompute", "vars/Execution.html#SymmetriesCompu
 insDoc(aux1, gLnk("R", "SymmetrizeDensity", "vars/States.html#SymmetrizeDensity"))
 insDoc(aux1, gLnk("R", "SymmetrizeDynamicalMatrix", "vars/Linear_Response.html#SymmetrizeDynamicalMatrix"))
 insDoc(aux1, gLnk("R", "SymmetryBreakDir", "vars/Mesh.html#SymmetryBreakDir"))
+insDoc(aux1, gLnk("R", "Systems", "vars/System.html#Systems"))
 aux1 = insFld(aux0, gFld("T", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "TDDeltaKickTime", "vars/Time-Dependent.html#TDDeltaKickTime"))
 insDoc(aux1, gLnk("R", "TDDeltaStrength", "vars/Time-Dependent.html#TDDeltaStrength"))
 insDoc(aux1, gLnk("R", "TDDeltaStrengthMode", "vars/Time-Dependent.html#TDDeltaStrengthMode"))
 insDoc(aux1, gLnk("R", "TDDeltaUserDefined", "vars/Time-Dependent.html#TDDeltaUserDefined"))
 insDoc(aux1, gLnk("R", "TDDynamics", "vars/Time-Dependent.html#TDDynamics"))
+insDoc(aux1, gLnk("R", "TDEasyAxis", "vars/Time-Dependent.html#TDEasyAxis"))
 insDoc(aux1, gLnk("R", "TDEnergyUpdateIter", "vars/Time-Dependent.html#TDEnergyUpdateIter"))
 insDoc(aux1, gLnk("R", "TDExcitedStatesToProject", "vars/Time-Dependent.html#TDExcitedStatesToProject"))
 insDoc(aux1, gLnk("R", "TDExponentialMethod", "vars/Time-Dependent.html#TDExponentialMethod"))
@@ -585,7 +641,10 @@ insDoc(aux1, gLnk("R", "TDIonicTimeScale", "vars/Time-Dependent.html#TDIonicTime
 insDoc(aux1, gLnk("R", "TDKickFunction", "vars/Time-Dependent.html#TDKickFunction"))
 insDoc(aux1, gLnk("R", "TDLanczosTol", "vars/Time-Dependent.html#TDLanczosTol"))
 insDoc(aux1, gLnk("R", "TDMaxSteps", "vars/Time-Dependent.html#TDMaxSteps"))
+insDoc(aux1, gLnk("R", "TDMaxwellKSRelaxationSteps", "vars/Time-Dependent.html#TDMaxwellKSRelaxationSteps"))
+insDoc(aux1, gLnk("R", "TDMaxwellTDRelaxationSteps", "vars/Time-Dependent.html#TDMaxwellTDRelaxationSteps"))
 insDoc(aux1, gLnk("R", "TDMomentumTransfer", "vars/Time-Dependent.html#TDMomentumTransfer"))
+insDoc(aux1, gLnk("R", "TDMultipleMomentumTransfer", "vars/Time-Dependent.html#TDMultipleMomentumTransfer"))
 insDoc(aux1, gLnk("R", "TDMultipoleLmax", "vars/Time-Dependent.html#TDMultipoleLmax"))
 insDoc(aux1, gLnk("R", "TDOutput", "vars/Time-Dependent.html#TDOutput"))
 insDoc(aux1, gLnk("R", "TDOutputComputeInterval", "vars/Time-Dependent.html#TDOutputComputeInterval"))
@@ -600,8 +659,10 @@ insDoc(aux1, gLnk("R", "TDPropagator", "vars/Time-Dependent.html#TDPropagator"))
 insDoc(aux1, gLnk("R", "TDSCFThreshold", "vars/Time-Dependent.html#TDSCFThreshold"))
 insDoc(aux1, gLnk("R", "TDScissor", "vars/Time-Dependent.html#TDScissor"))
 insDoc(aux1, gLnk("R", "TDStepsWithSelfConsistency", "vars/Time-Dependent.html#TDStepsWithSelfConsistency"))
+insDoc(aux1, gLnk("R", "TDSystemPropagator", "vars/Time-Dependent.html#TDSystemPropagator"))
 insDoc(aux1, gLnk("R", "TDTimeStep", "vars/Time-Dependent.html#TDTimeStep"))
 insDoc(aux1, gLnk("R", "TemperatureFunction", "vars/Time-Dependent.html#TemperatureFunction"))
+insDoc(aux1, gLnk("R", "TestBatchOps", "vars/Utilities.html#TestBatchOps"))
 insDoc(aux1, gLnk("R", "TestHamiltonianApply", "vars/Utilities.html#TestHamiltonianApply"))
 insDoc(aux1, gLnk("R", "TestMaxBlockSize", "vars/Utilities.html#TestMaxBlockSize"))
 insDoc(aux1, gLnk("R", "TestMinBlockSize", "vars/Utilities.html#TestMinBlockSize"))
@@ -616,12 +677,23 @@ insDoc(aux1, gLnk("R", "TotalStates", "vars/States.html#TotalStates"))
 insDoc(aux1, gLnk("R", "TransformStates", "vars/States.html#TransformStates"))
 insDoc(aux1, gLnk("R", "TransientAbsorptionReference", "vars/Utilities.html#TransientAbsorptionReference"))
 aux1 = insFld(aux0, gFld("U", "javascript:parent.op()"))
+insDoc(aux1, gLnk("R", "UnfoldEnergyStep", "vars/Utilities.html#UnfoldEnergyStep"))
+insDoc(aux1, gLnk("R", "UnfoldKPointsPath", "vars/Utilities.html#UnfoldKPointsPath"))
+insDoc(aux1, gLnk("R", "UnfoldLatticeParameters", "vars/Utilities.html#UnfoldLatticeParameters"))
+insDoc(aux1, gLnk("R", "UnfoldLatticeVectors", "vars/Utilities.html#UnfoldLatticeVectors"))
+insDoc(aux1, gLnk("R", "UnfoldMaxEnergy", "vars/Utilities.html#UnfoldMaxEnergy"))
+insDoc(aux1, gLnk("R", "UnfoldMinEnergy", "vars/Utilities.html#UnfoldMinEnergy"))
+insDoc(aux1, gLnk("R", "UnfoldMode", "vars/Utilities.html#UnfoldMode"))
 insDoc(aux1, gLnk("R", "Units", "vars/Execution.html#Units"))
 insDoc(aux1, gLnk("R", "UnitsOutput", "vars/Execution.html#UnitsOutput"))
 insDoc(aux1, gLnk("R", "UnitsXYZFiles", "vars/Execution.html#UnitsXYZFiles"))
 insDoc(aux1, gLnk("R", "UnoccShowOccStates", "vars/Calculation_Modes.html#UnoccShowOccStates"))
+insDoc(aux1, gLnk("R", "UnoccUseTD", "vars/Calculation_Modes.html#UnoccUseTD"))
 insDoc(aux1, gLnk("R", "UseAllAtomicOrbitals", "vars/Hamiltonian.html#UseAllAtomicOrbitals"))
 insDoc(aux1, gLnk("R", "UseFineMesh", "vars/Mesh.html#UseFineMesh"))
+insDoc(aux1, gLnk("R", "UserDefinedConstantSpacialMaxwellField", "vars/MaxwellStates.html#UserDefinedConstantSpacialMaxwellField"))
+insDoc(aux1, gLnk("R", "UserDefinedInitialMaxwellStates", "vars/MaxwellStates.html#UserDefinedInitialMaxwellStates"))
+insDoc(aux1, gLnk("R", "UserDefinedMaxwellExternalCurrent", "vars/MaxwellStates.html#UserDefinedMaxwellExternalCurrent"))
 insDoc(aux1, gLnk("R", "UserDefinedStates", "vars/States.html#UserDefinedStates"))
 aux1 = insFld(aux0, gFld("V", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "VDW_TS_cutoff", "vars/Hamiltonian.html#VDW_TS_cutoff"))
@@ -636,6 +708,12 @@ insDoc(aux1, gLnk("R", "VibrationalSpectrumTime", "vars/Utilities.html#Vibration
 insDoc(aux1, gLnk("R", "VibrationalSpectrumTimeStepFactor", "vars/Utilities.html#VibrationalSpectrumTimeStepFactor"))
 insDoc(aux1, gLnk("R", "Volume", "vars/Utilities.html#Volume"))
 aux1 = insFld(aux0, gFld("W", "javascript:parent.op()"))
+insDoc(aux1, gLnk("R", "Walltime", "vars/Execution.html#Walltime"))
+insDoc(aux1, gLnk("R", "Wannier90Files", "vars/Utilities.html#Wannier90Files"))
+insDoc(aux1, gLnk("R", "Wannier90Mode", "vars/Utilities.html#Wannier90Mode"))
+insDoc(aux1, gLnk("R", "Wannier90Prefix", "vars/Utilities.html#Wannier90Prefix"))
+insDoc(aux1, gLnk("R", "Wannier90UseSCDM", "vars/Utilities.html#Wannier90UseSCDM"))
+insDoc(aux1, gLnk("R", "Wannier90UseTD", "vars/Utilities.html#Wannier90UseTD"))
 insDoc(aux1, gLnk("R", "WatterstromODESolver", "vars/Math.html#WatterstromODESolver"))
 insDoc(aux1, gLnk("R", "WatterstromODESolverNSteps", "vars/Math.html#WatterstromODESolverNSteps"))
 insDoc(aux1, gLnk("R", "WorkDir", "vars/Execution.html#WorkDir"))
