@@ -5,6 +5,12 @@ ICONPATH = 'icons/'
 
 aux0 = gFld("Variables", "varsRightFrame.html")
 foldersTree = aux0
+aux1 = insFld(aux0, gFld("Atomic Orbitals", "vars/Atomic_Orbitals.html#Atomic_Orbitals"))
+insDoc(aux1, gLnk("R", "AOLoewdin", "vars/Atomic_Orbitals.html#AOLoewdin"))
+insDoc(aux1, gLnk("R", "AONormalize", "vars/Atomic_Orbitals.html#AONormalize"))
+insDoc(aux1, gLnk("R", "AOSubmeshForPeriodic", "vars/Atomic_Orbitals.html#AOSubmeshForPeriodic"))
+insDoc(aux1, gLnk("R", "AOThreshold", "vars/Atomic_Orbitals.html#AOThreshold"))
+insDoc(aux1, gLnk("R", "AOTruncation", "vars/Atomic_Orbitals.html#AOTruncation"))
 aux1 = insFld(aux0, gFld("Calculation Modes", "vars/Calculation_Modes.html#Calculation_Modes"))
 insDoc(aux1, gLnk("R", "CalculationMode", "vars/Calculation_Modes.html#CalculationMode"))
 aux2 = insFld(aux1, gFld("Geometry Optimization", "vars/Calculation_Modes.html#Calculation_Modes::Geometry_Optimization"))
@@ -79,14 +85,20 @@ insDoc(aux2, gLnk("R", "OCTVelocityDerivatives", "vars/Calculation_Modes.html#OC
 insDoc(aux2, gLnk("R", "OCTVelocityTarget", "vars/Calculation_Modes.html#OCTVelocityTarget"))
 aux2 = insFld(aux1, gFld("Unoccupied States", "vars/Calculation_Modes.html#Calculation_Modes::Unoccupied_States"))
 insDoc(aux2, gLnk("R", "UnoccShowOccStates", "vars/Calculation_Modes.html#UnoccShowOccStates"))
+insDoc(aux2, gLnk("R", "UnoccUseTD", "vars/Calculation_Modes.html#UnoccUseTD"))
+aux1 = insFld(aux0, gFld("ClassicalParticles", "vars/ClassicalParticles.html#ClassicalParticles"))
+insDoc(aux1, gLnk("R", "ClassicalParticleCharge", "vars/ClassicalParticles.html#ClassicalParticleCharge"))
+insDoc(aux1, gLnk("R", "ClassicalParticleInitialPosition", "vars/ClassicalParticles.html#ClassicalParticleInitialPosition"))
+insDoc(aux1, gLnk("R", "ClassicalParticleInitialVelocity", "vars/ClassicalParticles.html#ClassicalParticleInitialVelocity"))
+insDoc(aux1, gLnk("R", "ClassicalParticleMass", "vars/ClassicalParticles.html#ClassicalParticleMass"))
 aux1 = insFld(aux0, gFld("Execution", "vars/Execution.html#Execution"))
 insDoc(aux1, gLnk("R", "FromScratch", "vars/Execution.html#FromScratch"))
-insDoc(aux1, gLnk("R", "Splines", "vars/Execution.html#Splines"))
 aux2 = insFld(aux1, gFld("Accel", "vars/Execution.html#Execution::Accel"))
+insDoc(aux2, gLnk("R", "AccelBenchmark", "vars/Execution.html#AccelBenchmark"))
+insDoc(aux2, gLnk("R", "AccelDevice", "vars/Execution.html#AccelDevice"))
+insDoc(aux2, gLnk("R", "AccelPlatform", "vars/Execution.html#AccelPlatform"))
+insDoc(aux2, gLnk("R", "CudaAwareMPI", "vars/Execution.html#CudaAwareMPI"))
 insDoc(aux2, gLnk("R", "DisableAccel", "vars/Execution.html#DisableAccel"))
-insDoc(aux2, gLnk("R", "OpenCLBenchmark", "vars/Execution.html#OpenCLBenchmark"))
-insDoc(aux2, gLnk("R", "OpenCLDevice", "vars/Execution.html#OpenCLDevice"))
-insDoc(aux2, gLnk("R", "OpenCLPlatform", "vars/Execution.html#OpenCLPlatform"))
 aux2 = insFld(aux1, gFld("Debug", "vars/Execution.html#Execution::Debug"))
 insDoc(aux2, gLnk("R", "Debug", "vars/Execution.html#Debug"))
 insDoc(aux2, gLnk("R", "DebugTrapSignals", "vars/Execution.html#DebugTrapSignals"))
@@ -96,9 +108,12 @@ insDoc(aux2, gLnk("R", "MPIDebugHook", "vars/Execution.html#MPIDebugHook"))
 insDoc(aux2, gLnk("R", "ReportMemory", "vars/Execution.html#ReportMemory"))
 aux2 = insFld(aux1, gFld("IO", "vars/Execution.html#Execution::IO"))
 insDoc(aux2, gLnk("R", "FlushMessages", "vars/Execution.html#FlushMessages"))
+insDoc(aux2, gLnk("R", "MaxwellRestartWriteInterval", "vars/Execution.html#MaxwellRestartWriteInterval"))
 insDoc(aux2, gLnk("R", "RestartOptions", "vars/Execution.html#RestartOptions"))
 insDoc(aux2, gLnk("R", "RestartWrite", "vars/Execution.html#RestartWrite"))
 insDoc(aux2, gLnk("R", "RestartWriteInterval", "vars/Execution.html#RestartWriteInterval"))
+insDoc(aux2, gLnk("R", "RestartWriteTime", "vars/Execution.html#RestartWriteTime"))
+insDoc(aux2, gLnk("R", "Walltime", "vars/Execution.html#Walltime"))
 insDoc(aux2, gLnk("R", "WorkDir", "vars/Execution.html#WorkDir"))
 insDoc(aux2, gLnk("R", "stderr", "vars/Execution.html#stderr"))
 insDoc(aux2, gLnk("R", "stdout", "vars/Execution.html#stdout"))
@@ -108,16 +123,16 @@ insDoc(aux2, gLnk("R", "MemoryLimit", "vars/Execution.html#MemoryLimit"))
 insDoc(aux2, gLnk("R", "MeshBlockSize", "vars/Execution.html#MeshBlockSize"))
 insDoc(aux2, gLnk("R", "MeshOrder", "vars/Execution.html#MeshOrder"))
 insDoc(aux2, gLnk("R", "NLOperatorCompactBoundaries", "vars/Execution.html#NLOperatorCompactBoundaries"))
+insDoc(aux2, gLnk("R", "OperateAccel", "vars/Execution.html#OperateAccel"))
 insDoc(aux2, gLnk("R", "OperateComplex", "vars/Execution.html#OperateComplex"))
 insDoc(aux2, gLnk("R", "OperateComplexSingle", "vars/Execution.html#OperateComplexSingle"))
 insDoc(aux2, gLnk("R", "OperateDouble", "vars/Execution.html#OperateDouble"))
-insDoc(aux2, gLnk("R", "OperateOpenCL", "vars/Execution.html#OperateOpenCL"))
 insDoc(aux2, gLnk("R", "OperateSingle", "vars/Execution.html#OperateSingle"))
 insDoc(aux2, gLnk("R", "ProfilingAllNodes", "vars/Execution.html#ProfilingAllNodes"))
 insDoc(aux2, gLnk("R", "ProfilingMode", "vars/Execution.html#ProfilingMode"))
+insDoc(aux2, gLnk("R", "ProfilingOutputYAML", "vars/Execution.html#ProfilingOutputYAML"))
 insDoc(aux2, gLnk("R", "StatesBlockSize", "vars/Execution.html#StatesBlockSize"))
 insDoc(aux2, gLnk("R", "StatesCLDeviceMemory", "vars/Execution.html#StatesCLDeviceMemory"))
-insDoc(aux2, gLnk("R", "StatesMirror", "vars/Execution.html#StatesMirror"))
 insDoc(aux2, gLnk("R", "StatesPack", "vars/Execution.html#StatesPack"))
 aux2 = insFld(aux1, gFld("Parallelization", "vars/Execution.html#Execution::Parallelization"))
 insDoc(aux2, gLnk("R", "MeshPartition", "vars/Execution.html#MeshPartition"))
@@ -134,6 +149,7 @@ insDoc(aux2, gLnk("R", "ParallelizationNumberSlaves", "vars/Execution.html#Paral
 insDoc(aux2, gLnk("R", "ParallelizationOfDerivatives", "vars/Execution.html#ParallelizationOfDerivatives"))
 insDoc(aux2, gLnk("R", "ParallelizationPoissonAllNodes", "vars/Execution.html#ParallelizationPoissonAllNodes"))
 insDoc(aux2, gLnk("R", "PartitionPrint", "vars/Execution.html#PartitionPrint"))
+insDoc(aux2, gLnk("R", "ReorderRanks", "vars/Execution.html#ReorderRanks"))
 insDoc(aux2, gLnk("R", "ScaLAPACKCompatible", "vars/Execution.html#ScaLAPACKCompatible"))
 aux2 = insFld(aux1, gFld("Symmetries", "vars/Execution.html#Execution::Symmetries"))
 insDoc(aux2, gLnk("R", "SymmetriesCompute", "vars/Execution.html#SymmetriesCompute"))
@@ -146,6 +162,7 @@ insDoc(aux1, gLnk("R", "CalculateSelfInducedMagneticField", "vars/Hamiltonian.ht
 insDoc(aux1, gLnk("R", "ClassicalPotential", "vars/Hamiltonian.html#ClassicalPotential"))
 insDoc(aux1, gLnk("R", "CurrentDensity", "vars/Hamiltonian.html#CurrentDensity"))
 insDoc(aux1, gLnk("R", "EwaldAlpha", "vars/Hamiltonian.html#EwaldAlpha"))
+insDoc(aux1, gLnk("R", "ExternalCurrent", "vars/Hamiltonian.html#ExternalCurrent"))
 insDoc(aux1, gLnk("R", "FilterPotentials", "vars/Hamiltonian.html#FilterPotentials"))
 insDoc(aux1, gLnk("R", "ForceTotalEnforce", "vars/Hamiltonian.html#ForceTotalEnforce"))
 insDoc(aux1, gLnk("R", "GaugeFieldDelay", "vars/Hamiltonian.html#GaugeFieldDelay"))
@@ -155,9 +172,12 @@ insDoc(aux1, gLnk("R", "GaugeVectorField", "vars/Hamiltonian.html#GaugeVectorFie
 insDoc(aux1, gLnk("R", "GyromagneticRatio", "vars/Hamiltonian.html#GyromagneticRatio"))
 insDoc(aux1, gLnk("R", "IgnoreExternalIons", "vars/Hamiltonian.html#IgnoreExternalIons"))
 insDoc(aux1, gLnk("R", "MassScaling", "vars/Hamiltonian.html#MassScaling"))
+insDoc(aux1, gLnk("R", "MaxwellHamiltonianOperator", "vars/Hamiltonian.html#MaxwellHamiltonianOperator"))
+insDoc(aux1, gLnk("R", "MaxwellMediumCalculation", "vars/Hamiltonian.html#MaxwellMediumCalculation"))
 insDoc(aux1, gLnk("R", "ParticleMass", "vars/Hamiltonian.html#ParticleMass"))
 insDoc(aux1, gLnk("R", "RashbaSpinOrbitCoupling", "vars/Hamiltonian.html#RashbaSpinOrbitCoupling"))
 insDoc(aux1, gLnk("R", "RelativisticCorrection", "vars/Hamiltonian.html#RelativisticCorrection"))
+insDoc(aux1, gLnk("R", "RiemannSilbersteinSign", "vars/Hamiltonian.html#RiemannSilbersteinSign"))
 insDoc(aux1, gLnk("R", "SCDMCutoffRadius", "vars/Hamiltonian.html#SCDMCutoffRadius"))
 insDoc(aux1, gLnk("R", "SCDM_EXX", "vars/Hamiltonian.html#SCDM_EXX"))
 insDoc(aux1, gLnk("R", "SCDM_verbose", "vars/Hamiltonian.html#SCDM_verbose"))
@@ -168,16 +188,14 @@ insDoc(aux1, gLnk("R", "StaticMagneticField2DGauge", "vars/Hamiltonian.html#Stat
 insDoc(aux1, gLnk("R", "TheoryLevel", "vars/Hamiltonian.html#TheoryLevel"))
 insDoc(aux1, gLnk("R", "TimeZero", "vars/Hamiltonian.html#TimeZero"))
 aux2 = insFld(aux1, gFld("DFT+U", "vars/Hamiltonian.html#Hamiltonian::DFT+U"))
+insDoc(aux2, gLnk("R", "ACBN0IntersiteCutoff", "vars/Hamiltonian.html#ACBN0IntersiteCutoff"))
+insDoc(aux2, gLnk("R", "ACBN0IntersiteInteraction", "vars/Hamiltonian.html#ACBN0IntersiteInteraction"))
 insDoc(aux2, gLnk("R", "ACBN0RotationallyInvariant", "vars/Hamiltonian.html#ACBN0RotationallyInvariant"))
 insDoc(aux2, gLnk("R", "ACBN0Screening", "vars/Hamiltonian.html#ACBN0Screening"))
-insDoc(aux2, gLnk("R", "AOLoewdin", "vars/Hamiltonian.html#AOLoewdin"))
-insDoc(aux2, gLnk("R", "AONormalize", "vars/Hamiltonian.html#AONormalize"))
-insDoc(aux2, gLnk("R", "AOSubmeshForPeriodic", "vars/Hamiltonian.html#AOSubmeshForPeriodic"))
-insDoc(aux2, gLnk("R", "AOThreshold", "vars/Hamiltonian.html#AOThreshold"))
-insDoc(aux2, gLnk("R", "AOTruncation", "vars/Hamiltonian.html#AOTruncation"))
 insDoc(aux2, gLnk("R", "DFTUBasisFromStates", "vars/Hamiltonian.html#DFTUBasisFromStates"))
 insDoc(aux2, gLnk("R", "DFTUBasisStates", "vars/Hamiltonian.html#DFTUBasisStates"))
 insDoc(aux2, gLnk("R", "DFTUDoubleCounting", "vars/Hamiltonian.html#DFTUDoubleCounting"))
+insDoc(aux2, gLnk("R", "DFTUPoissonSolver", "vars/Hamiltonian.html#DFTUPoissonSolver"))
 insDoc(aux2, gLnk("R", "SkipSOrbitals", "vars/Hamiltonian.html#SkipSOrbitals"))
 insDoc(aux2, gLnk("R", "UseAllAtomicOrbitals", "vars/Hamiltonian.html#UseAllAtomicOrbitals"))
 aux2 = insFld(aux1, gFld("PCM", "vars/Hamiltonian.html#Hamiltonian::PCM"))
@@ -189,13 +207,11 @@ insDoc(aux2, gLnk("R", "PCMDebyeRelaxTime", "vars/Hamiltonian.html#PCMDebyeRelax
 insDoc(aux2, gLnk("R", "PCMDrudeLDamping", "vars/Hamiltonian.html#PCMDrudeLDamping"))
 insDoc(aux2, gLnk("R", "PCMDrudeLOmega", "vars/Hamiltonian.html#PCMDrudeLOmega"))
 insDoc(aux2, gLnk("R", "PCMDynamicEpsilon", "vars/Hamiltonian.html#PCMDynamicEpsilon"))
-insDoc(aux2, gLnk("R", "PCMEoM", "vars/Hamiltonian.html#PCMEoM"))
 insDoc(aux2, gLnk("R", "PCMEoMInitialCharges", "vars/Hamiltonian.html#PCMEoMInitialCharges"))
 insDoc(aux2, gLnk("R", "PCMEpsilonModel", "vars/Hamiltonian.html#PCMEpsilonModel"))
 insDoc(aux2, gLnk("R", "PCMGamessBenchmark", "vars/Hamiltonian.html#PCMGamessBenchmark"))
 insDoc(aux2, gLnk("R", "PCMKick", "vars/Hamiltonian.html#PCMKick"))
 insDoc(aux2, gLnk("R", "PCMLocalField", "vars/Hamiltonian.html#PCMLocalField"))
-insDoc(aux2, gLnk("R", "PCMNonequilibrium", "vars/Hamiltonian.html#PCMNonequilibrium"))
 insDoc(aux2, gLnk("R", "PCMQtotTol", "vars/Hamiltonian.html#PCMQtotTol"))
 insDoc(aux2, gLnk("R", "PCMRadiusScaling", "vars/Hamiltonian.html#PCMRadiusScaling"))
 insDoc(aux2, gLnk("R", "PCMRenormCharges", "vars/Hamiltonian.html#PCMRenormCharges"))
@@ -203,6 +219,7 @@ insDoc(aux2, gLnk("R", "PCMSmearingFactor", "vars/Hamiltonian.html#PCMSmearingFa
 insDoc(aux2, gLnk("R", "PCMSolute", "vars/Hamiltonian.html#PCMSolute"))
 insDoc(aux2, gLnk("R", "PCMSpheresOnH", "vars/Hamiltonian.html#PCMSpheresOnH"))
 insDoc(aux2, gLnk("R", "PCMStaticEpsilon", "vars/Hamiltonian.html#PCMStaticEpsilon"))
+insDoc(aux2, gLnk("R", "PCMTDLevel", "vars/Hamiltonian.html#PCMTDLevel"))
 insDoc(aux2, gLnk("R", "PCMTessMinDistance", "vars/Hamiltonian.html#PCMTessMinDistance"))
 insDoc(aux2, gLnk("R", "PCMTessSubdivider", "vars/Hamiltonian.html#PCMTessSubdivider"))
 insDoc(aux2, gLnk("R", "PCMUpdateIter", "vars/Hamiltonian.html#PCMUpdateIter"))
@@ -210,6 +227,7 @@ insDoc(aux2, gLnk("R", "PCMVdWRadii", "vars/Hamiltonian.html#PCMVdWRadii"))
 aux2 = insFld(aux1, gFld("Poisson", "vars/Hamiltonian.html#Hamiltonian::Poisson"))
 insDoc(aux2, gLnk("R", "AlphaFMM", "vars/Hamiltonian.html#AlphaFMM"))
 insDoc(aux2, gLnk("R", "DeltaEFMM", "vars/Hamiltonian.html#DeltaEFMM"))
+insDoc(aux2, gLnk("R", "DressedOrbitals", "vars/Hamiltonian.html#DressedOrbitals"))
 insDoc(aux2, gLnk("R", "Poisson1DSoftCoulombParam", "vars/Hamiltonian.html#Poisson1DSoftCoulombParam"))
 insDoc(aux2, gLnk("R", "PoissonCutoffRadius", "vars/Hamiltonian.html#PoissonCutoffRadius"))
 insDoc(aux2, gLnk("R", "PoissonFFTKernel", "vars/Hamiltonian.html#PoissonFFTKernel"))
@@ -219,8 +237,6 @@ insDoc(aux2, gLnk("R", "PoissonSolverMaxIter", "vars/Hamiltonian.html#PoissonSol
 insDoc(aux2, gLnk("R", "PoissonSolverMaxMultipole", "vars/Hamiltonian.html#PoissonSolverMaxMultipole"))
 insDoc(aux2, gLnk("R", "PoissonSolverNodes", "vars/Hamiltonian.html#PoissonSolverNodes"))
 insDoc(aux2, gLnk("R", "PoissonSolverThreshold", "vars/Hamiltonian.html#PoissonSolverThreshold"))
-aux3 = insFld(aux2, gFld("ISF", "vars/Hamiltonian.html#Hamiltonian::Poisson::ISF"))
-insDoc(aux3, gLnk("R", "PoissonSolverISFParallelData", "vars/Hamiltonian.html#PoissonSolverISFParallelData"))
 aux3 = insFld(aux2, gFld("Multigrid", "vars/Hamiltonian.html#Hamiltonian::Poisson::Multigrid"))
 insDoc(aux3, gLnk("R", "PoissonSolverMGMaxCycles", "vars/Hamiltonian.html#PoissonSolverMGMaxCycles"))
 insDoc(aux3, gLnk("R", "PoissonSolverMGPostsmoothingSteps", "vars/Hamiltonian.html#PoissonSolverMGPostsmoothingSteps"))
@@ -228,14 +244,21 @@ insDoc(aux3, gLnk("R", "PoissonSolverMGPresmoothingSteps", "vars/Hamiltonian.htm
 insDoc(aux3, gLnk("R", "PoissonSolverMGRelaxationFactor", "vars/Hamiltonian.html#PoissonSolverMGRelaxationFactor"))
 insDoc(aux3, gLnk("R", "PoissonSolverMGRelaxationMethod", "vars/Hamiltonian.html#PoissonSolverMGRelaxationMethod"))
 insDoc(aux3, gLnk("R", "PoissonSolverMGRestrictionMethod", "vars/Hamiltonian.html#PoissonSolverMGRestrictionMethod"))
+aux3 = insFld(aux2, gFld("PSolver", "vars/Hamiltonian.html#Hamiltonian::Poisson::PSolver"))
+insDoc(aux3, gLnk("R", "PoissonSolverPSolverParallelData", "vars/Hamiltonian.html#PoissonSolverPSolverParallelData"))
 aux2 = insFld(aux1, gFld("XC", "vars/Hamiltonian.html#Hamiltonian::XC"))
 insDoc(aux2, gLnk("R", "DFTULevel", "vars/Hamiltonian.html#DFTULevel"))
+insDoc(aux2, gLnk("R", "HFSingularity", "vars/Hamiltonian.html#HFSingularity"))
+insDoc(aux2, gLnk("R", "HFSingularityNk", "vars/Hamiltonian.html#HFSingularityNk"))
+insDoc(aux2, gLnk("R", "HFSingularityNsteps", "vars/Hamiltonian.html#HFSingularityNsteps"))
 insDoc(aux2, gLnk("R", "Interaction1D", "vars/Hamiltonian.html#Interaction1D"))
 insDoc(aux2, gLnk("R", "Interaction1DScreening", "vars/Hamiltonian.html#Interaction1DScreening"))
-insDoc(aux2, gLnk("R", "LB94_modified", "vars/Hamiltonian.html#LB94_modified"))
-insDoc(aux2, gLnk("R", "LB94_threshold", "vars/Hamiltonian.html#LB94_threshold"))
+insDoc(aux2, gLnk("R", "KLIPhotonCOC", "vars/Hamiltonian.html#KLIPhotonCOC"))
 insDoc(aux2, gLnk("R", "OEPLevel", "vars/Hamiltonian.html#OEPLevel"))
 insDoc(aux2, gLnk("R", "OEPMixing", "vars/Hamiltonian.html#OEPMixing"))
+insDoc(aux2, gLnk("R", "OEPMixingScheme", "vars/Hamiltonian.html#OEPMixingScheme"))
+insDoc(aux2, gLnk("R", "PhotonModes", "vars/Hamiltonian.html#PhotonModes"))
+insDoc(aux2, gLnk("R", "Photons", "vars/Hamiltonian.html#Photons"))
 insDoc(aux2, gLnk("R", "SICCorrection", "vars/Hamiltonian.html#SICCorrection"))
 insDoc(aux2, gLnk("R", "VDWCorrection", "vars/Hamiltonian.html#VDWCorrection"))
 insDoc(aux2, gLnk("R", "VDWD3Functional", "vars/Hamiltonian.html#VDWD3Functional"))
@@ -341,13 +364,20 @@ insDoc(aux2, gLnk("R", "SPARSKITMaxIter", "vars/Math.html#SPARSKITMaxIter"))
 insDoc(aux2, gLnk("R", "SPARSKITRelTolerance", "vars/Math.html#SPARSKITRelTolerance"))
 insDoc(aux2, gLnk("R", "SPARSKITSolver", "vars/Math.html#SPARSKITSolver"))
 insDoc(aux2, gLnk("R", "SPARSKITVerboseSolver", "vars/Math.html#SPARSKITVerboseSolver"))
+aux1 = insFld(aux0, gFld("MaxwellStates", "vars/MaxwellStates.html#MaxwellStates"))
+insDoc(aux1, gLnk("R", "MaxwellIncidentWaves", "vars/MaxwellStates.html#MaxwellIncidentWaves"))
+insDoc(aux1, gLnk("R", "UserDefinedConstantSpacialMaxwellField", "vars/MaxwellStates.html#UserDefinedConstantSpacialMaxwellField"))
+insDoc(aux1, gLnk("R", "UserDefinedInitialMaxwellStates", "vars/MaxwellStates.html#UserDefinedInitialMaxwellStates"))
+insDoc(aux1, gLnk("R", "UserDefinedMaxwellExternalCurrent", "vars/MaxwellStates.html#UserDefinedMaxwellExternalCurrent"))
 aux1 = insFld(aux0, gFld("Mesh", "vars/Mesh.html#Mesh"))
 insDoc(aux1, gLnk("R", "DoubleGrid", "vars/Mesh.html#DoubleGrid"))
 insDoc(aux1, gLnk("R", "DoubleGridOrder", "vars/Mesh.html#DoubleGridOrder"))
 insDoc(aux1, gLnk("R", "MultiResolutionArea", "vars/Mesh.html#MultiResolutionArea"))
 insDoc(aux1, gLnk("R", "MultiResolutionInterpolationOrder", "vars/Mesh.html#MultiResolutionInterpolationOrder"))
 insDoc(aux1, gLnk("R", "MultigridLevels", "vars/Mesh.html#MultigridLevels"))
+insDoc(aux1, gLnk("R", "PeriodicBoundaryMask", "vars/Mesh.html#PeriodicBoundaryMask"))
 insDoc(aux1, gLnk("R", "Spacing", "vars/Mesh.html#Spacing"))
+insDoc(aux1, gLnk("R", "SpiralBoundaryCondition", "vars/Mesh.html#SpiralBoundaryCondition"))
 insDoc(aux1, gLnk("R", "UseFineMesh", "vars/Mesh.html#UseFineMesh"))
 aux2 = insFld(aux1, gFld("Curvilinear", "vars/Mesh.html#Mesh::Curvilinear"))
 insDoc(aux2, gLnk("R", "CurvMethod", "vars/Mesh.html#CurvMethod"))
@@ -382,6 +412,7 @@ insDoc(aux2, gLnk("R", "KPointsPath", "vars/Mesh.html#KPointsPath"))
 insDoc(aux2, gLnk("R", "KPointsReduced", "vars/Mesh.html#KPointsReduced"))
 insDoc(aux2, gLnk("R", "KPointsUseSymmetries", "vars/Mesh.html#KPointsUseSymmetries"))
 insDoc(aux2, gLnk("R", "KPointsUseTimeReversal", "vars/Mesh.html#KPointsUseTimeReversal"))
+insDoc(aux2, gLnk("R", "QPointsGrid", "vars/Mesh.html#QPointsGrid"))
 aux2 = insFld(aux1, gFld("Simulation Box", "vars/Mesh.html#Mesh::Simulation_Box"))
 insDoc(aux2, gLnk("R", "BoxShape", "vars/Mesh.html#BoxShape"))
 insDoc(aux2, gLnk("R", "BoxShapeImage", "vars/Mesh.html#BoxShapeImage"))
@@ -402,6 +433,9 @@ insDoc(aux1, gLnk("R", "DOSEnergyPoints", "vars/Output.html#DOSEnergyPoints"))
 insDoc(aux1, gLnk("R", "DOSGamma", "vars/Output.html#DOSGamma"))
 insDoc(aux1, gLnk("R", "ELFWithCurrentTerm", "vars/Output.html#ELFWithCurrentTerm"))
 insDoc(aux1, gLnk("R", "LocalMagneticMomentsSphereRadius", "vars/Output.html#LocalMagneticMomentsSphereRadius"))
+insDoc(aux1, gLnk("R", "MaxwellOutput", "vars/Output.html#MaxwellOutput"))
+insDoc(aux1, gLnk("R", "MaxwellOutputInterval", "vars/Output.html#MaxwellOutputInterval"))
+insDoc(aux1, gLnk("R", "MaxwellOutputIterDir", "vars/Output.html#MaxwellOutputIterDir"))
 insDoc(aux1, gLnk("R", "MomentumTransfer", "vars/Output.html#MomentumTransfer"))
 insDoc(aux1, gLnk("R", "Output", "vars/Output.html#Output"))
 insDoc(aux1, gLnk("R", "OutputDuringSCF", "vars/Output.html#OutputDuringSCF"))
@@ -409,7 +443,9 @@ insDoc(aux1, gLnk("R", "OutputFormat", "vars/Output.html#OutputFormat"))
 insDoc(aux1, gLnk("R", "OutputInterval", "vars/Output.html#OutputInterval"))
 insDoc(aux1, gLnk("R", "OutputIterDir", "vars/Output.html#OutputIterDir"))
 insDoc(aux1, gLnk("R", "OutputLDA_U", "vars/Output.html#OutputLDA_U"))
+insDoc(aux1, gLnk("R", "OutputMEEnd", "vars/Output.html#OutputMEEnd"))
 insDoc(aux1, gLnk("R", "OutputMEMultipoles", "vars/Output.html#OutputMEMultipoles"))
+insDoc(aux1, gLnk("R", "OutputMEStart", "vars/Output.html#OutputMEStart"))
 insDoc(aux1, gLnk("R", "OutputMatrixElements", "vars/Output.html#OutputMatrixElements"))
 insDoc(aux1, gLnk("R", "OutputWfsNumber", "vars/Output.html#OutputWfsNumber"))
 insDoc(aux1, gLnk("R", "Output_KPT", "vars/Output.html#Output_KPT"))
@@ -445,6 +481,7 @@ insDoc(aux2, gLnk("R", "MaximumIterBerry", "vars/SCF.html#MaximumIterBerry"))
 aux2 = insFld(aux1, gFld("Eigensolver", "vars/SCF.html#SCF::Eigensolver"))
 insDoc(aux2, gLnk("R", "CGAdditionalTerms", "vars/SCF.html#CGAdditionalTerms"))
 insDoc(aux2, gLnk("R", "CGDirection", "vars/SCF.html#CGDirection"))
+insDoc(aux2, gLnk("R", "CGEnergyChangeThreshold", "vars/SCF.html#CGEnergyChangeThreshold"))
 insDoc(aux2, gLnk("R", "CGOrthogonalizeAll", "vars/SCF.html#CGOrthogonalizeAll"))
 insDoc(aux2, gLnk("R", "Eigensolver", "vars/SCF.html#Eigensolver"))
 insDoc(aux2, gLnk("R", "EigensolverImaginaryTime", "vars/SCF.html#EigensolverImaginaryTime"))
@@ -482,13 +519,16 @@ insDoc(aux2, gLnk("R", "MixingScheme", "vars/SCF.html#MixingScheme"))
 aux2 = insFld(aux1, gFld("RDMFT", "vars/SCF.html#SCF::RDMFT"))
 insDoc(aux2, gLnk("R", "RDMBasis", "vars/SCF.html#RDMBasis"))
 insDoc(aux2, gLnk("R", "RDMConvEner", "vars/SCF.html#RDMConvEner"))
+insDoc(aux2, gLnk("R", "RDMHartreeFock", "vars/SCF.html#RDMHartreeFock"))
 insDoc(aux2, gLnk("R", "RDMTolerance", "vars/SCF.html#RDMTolerance"))
+insDoc(aux2, gLnk("R", "RDMToleranceFO", "vars/SCF.html#RDMToleranceFO"))
 aux1 = insFld(aux0, gFld("States", "vars/States.html#States"))
 insDoc(aux1, gLnk("R", "DegeneracyThreshold", "vars/States.html#DegeneracyThreshold"))
 insDoc(aux1, gLnk("R", "ExcessCharge", "vars/States.html#ExcessCharge"))
 insDoc(aux1, gLnk("R", "ExtraStates", "vars/States.html#ExtraStates"))
 insDoc(aux1, gLnk("R", "ExtraStatesToConverge", "vars/States.html#ExtraStatesToConverge"))
 insDoc(aux1, gLnk("R", "InitialSpins", "vars/States.html#InitialSpins"))
+insDoc(aux1, gLnk("R", "MaxwellPlaneWavesInBox", "vars/States.html#MaxwellPlaneWavesInBox"))
 insDoc(aux1, gLnk("R", "Occupations", "vars/States.html#Occupations"))
 insDoc(aux1, gLnk("R", "OnlyUserDefinedInitialStates", "vars/States.html#OnlyUserDefinedInitialStates"))
 insDoc(aux1, gLnk("R", "RestartFixedOccupations", "vars/States.html#RestartFixedOccupations"))
@@ -511,8 +551,10 @@ insDoc(aux2, gLnk("R", "NTypeParticleModelmb", "vars/States.html#NTypeParticleMo
 aux1 = insFld(aux0, gFld("System", "vars/System.html#System"))
 insDoc(aux1, gLnk("R", "Dimensions", "vars/System.html#Dimensions"))
 insDoc(aux1, gLnk("R", "PeriodicDimensions", "vars/System.html#PeriodicDimensions"))
+insDoc(aux1, gLnk("R", "Systems", "vars/System.html#Systems"))
 aux2 = insFld(aux1, gFld("Coordinates", "vars/System.html#System::Coordinates"))
 insDoc(aux2, gLnk("R", "Coordinates", "vars/System.html#Coordinates"))
+insDoc(aux2, gLnk("R", "MaxwellFieldsCoordinate", "vars/System.html#MaxwellFieldsCoordinate"))
 insDoc(aux2, gLnk("R", "PDBClassical", "vars/System.html#PDBClassical"))
 insDoc(aux2, gLnk("R", "PDBCoordinates", "vars/System.html#PDBCoordinates"))
 insDoc(aux2, gLnk("R", "ReducedCoordinates", "vars/System.html#ReducedCoordinates"))
@@ -533,6 +575,7 @@ insDoc(aux2, gLnk("R", "Velocities", "vars/System.html#Velocities"))
 insDoc(aux2, gLnk("R", "XSFVelocities", "vars/System.html#XSFVelocities"))
 insDoc(aux2, gLnk("R", "XYZVelocities", "vars/System.html#XYZVelocities"))
 aux1 = insFld(aux0, gFld("Time-Dependent", "vars/Time-Dependent.html#Time-Dependent"))
+insDoc(aux1, gLnk("R", "MaxwellFunctions", "vars/Time-Dependent.html#MaxwellFunctions"))
 insDoc(aux1, gLnk("R", "TDExternalFields", "vars/Time-Dependent.html#TDExternalFields"))
 insDoc(aux1, gLnk("R", "TDFreezeDFTUOccupations", "vars/Time-Dependent.html#TDFreezeDFTUOccupations"))
 insDoc(aux1, gLnk("R", "TDFreezeHXC", "vars/Time-Dependent.html#TDFreezeHXC"))
@@ -546,6 +589,14 @@ insDoc(aux2, gLnk("R", "ABCapHeight", "vars/Time-Dependent.html#ABCapHeight"))
 insDoc(aux2, gLnk("R", "ABShape", "vars/Time-Dependent.html#ABShape"))
 insDoc(aux2, gLnk("R", "ABWidth", "vars/Time-Dependent.html#ABWidth"))
 insDoc(aux2, gLnk("R", "AbsorbingBoundaries", "vars/Time-Dependent.html#AbsorbingBoundaries"))
+insDoc(aux2, gLnk("R", "MaxwellABPMLPower", "vars/Time-Dependent.html#MaxwellABPMLPower"))
+insDoc(aux2, gLnk("R", "MaxwellABPMLReflectionError", "vars/Time-Dependent.html#MaxwellABPMLReflectionError"))
+insDoc(aux2, gLnk("R", "MaxwellABWidth", "vars/Time-Dependent.html#MaxwellABWidth"))
+insDoc(aux2, gLnk("R", "MediumElectricSigma", "vars/Time-Dependent.html#MediumElectricSigma"))
+insDoc(aux2, gLnk("R", "MediumEpsilonFactor", "vars/Time-Dependent.html#MediumEpsilonFactor"))
+insDoc(aux2, gLnk("R", "MediumMagneticSigma", "vars/Time-Dependent.html#MediumMagneticSigma"))
+insDoc(aux2, gLnk("R", "MediumMuFactor", "vars/Time-Dependent.html#MediumMuFactor"))
+insDoc(aux2, gLnk("R", "MediumWidth", "vars/Time-Dependent.html#MediumWidth"))
 aux2 = insFld(aux1, gFld("PhotoElectronSpectrum", "vars/Time-Dependent.html#Time-Dependent::PhotoElectronSpectrum"))
 insDoc(aux2, gLnk("R", "PESMask2PEnlargeFactor", "vars/Time-Dependent.html#PESMask2PEnlargeFactor"))
 insDoc(aux2, gLnk("R", "PESMaskEnlargeFactor", "vars/Time-Dependent.html#PESMaskEnlargeFactor"))
@@ -587,6 +638,13 @@ aux2 = insFld(aux1, gFld("Propagation", "vars/Time-Dependent.html#Time-Dependent
 insDoc(aux2, gLnk("R", "ArnoldiOrthogonalization", "vars/Time-Dependent.html#ArnoldiOrthogonalization"))
 insDoc(aux2, gLnk("R", "IonsConstantVelocity", "vars/Time-Dependent.html#IonsConstantVelocity"))
 insDoc(aux2, gLnk("R", "IonsTimeDependentDisplacements", "vars/Time-Dependent.html#IonsTimeDependentDisplacements"))
+insDoc(aux2, gLnk("R", "MaxwellAbsorbingBoundaries", "vars/Time-Dependent.html#MaxwellAbsorbingBoundaries"))
+insDoc(aux2, gLnk("R", "MaxwellBoundaryConditions", "vars/Time-Dependent.html#MaxwellBoundaryConditions"))
+insDoc(aux2, gLnk("R", "MaxwellMediumBox", "vars/Time-Dependent.html#MaxwellMediumBox"))
+insDoc(aux2, gLnk("R", "MaxwellTDETRSApprox", "vars/Time-Dependent.html#MaxwellTDETRSApprox"))
+insDoc(aux2, gLnk("R", "MaxwellTDIntervalSteps", "vars/Time-Dependent.html#MaxwellTDIntervalSteps"))
+insDoc(aux2, gLnk("R", "MaxwellTDOperatorMethod", "vars/Time-Dependent.html#MaxwellTDOperatorMethod"))
+insDoc(aux2, gLnk("R", "MaxwellTDSCFThreshold", "vars/Time-Dependent.html#MaxwellTDSCFThreshold"))
 insDoc(aux2, gLnk("R", "MoveIons", "vars/Time-Dependent.html#MoveIons"))
 insDoc(aux2, gLnk("R", "RecalculateGSDuringEvolution", "vars/Time-Dependent.html#RecalculateGSDuringEvolution"))
 insDoc(aux2, gLnk("R", "TDDynamics", "vars/Time-Dependent.html#TDDynamics"))
@@ -596,10 +654,13 @@ insDoc(aux2, gLnk("R", "TDExponentialMethod", "vars/Time-Dependent.html#TDExpone
 insDoc(aux2, gLnk("R", "TDIonicTimeScale", "vars/Time-Dependent.html#TDIonicTimeScale"))
 insDoc(aux2, gLnk("R", "TDLanczosTol", "vars/Time-Dependent.html#TDLanczosTol"))
 insDoc(aux2, gLnk("R", "TDMaxSteps", "vars/Time-Dependent.html#TDMaxSteps"))
+insDoc(aux2, gLnk("R", "TDMaxwellKSRelaxationSteps", "vars/Time-Dependent.html#TDMaxwellKSRelaxationSteps"))
+insDoc(aux2, gLnk("R", "TDMaxwellTDRelaxationSteps", "vars/Time-Dependent.html#TDMaxwellTDRelaxationSteps"))
 insDoc(aux2, gLnk("R", "TDPropagationTime", "vars/Time-Dependent.html#TDPropagationTime"))
 insDoc(aux2, gLnk("R", "TDPropagator", "vars/Time-Dependent.html#TDPropagator"))
 insDoc(aux2, gLnk("R", "TDSCFThreshold", "vars/Time-Dependent.html#TDSCFThreshold"))
 insDoc(aux2, gLnk("R", "TDStepsWithSelfConsistency", "vars/Time-Dependent.html#TDStepsWithSelfConsistency"))
+insDoc(aux2, gLnk("R", "TDSystemPropagator", "vars/Time-Dependent.html#TDSystemPropagator"))
 insDoc(aux2, gLnk("R", "TDTimeStep", "vars/Time-Dependent.html#TDTimeStep"))
 insDoc(aux2, gLnk("R", "TemperatureFunction", "vars/Time-Dependent.html#TemperatureFunction"))
 insDoc(aux2, gLnk("R", "Thermostat", "vars/Time-Dependent.html#Thermostat"))
@@ -611,12 +672,15 @@ insDoc(aux2, gLnk("R", "TDDeltaStrengthMode", "vars/Time-Dependent.html#TDDeltaS
 insDoc(aux2, gLnk("R", "TDDeltaUserDefined", "vars/Time-Dependent.html#TDDeltaUserDefined"))
 insDoc(aux2, gLnk("R", "TDKickFunction", "vars/Time-Dependent.html#TDKickFunction"))
 insDoc(aux2, gLnk("R", "TDMomentumTransfer", "vars/Time-Dependent.html#TDMomentumTransfer"))
+insDoc(aux2, gLnk("R", "TDMultipleMomentumTransfer", "vars/Time-Dependent.html#TDMultipleMomentumTransfer"))
 aux3 = insFld(aux2, gFld("Dipole", "vars/Time-Dependent.html#Time-Dependent::Response::Dipole"))
+insDoc(aux3, gLnk("R", "TDEasyAxis", "vars/Time-Dependent.html#TDEasyAxis"))
 insDoc(aux3, gLnk("R", "TDPolarization", "vars/Time-Dependent.html#TDPolarization"))
 insDoc(aux3, gLnk("R", "TDPolarizationDirection", "vars/Time-Dependent.html#TDPolarizationDirection"))
 insDoc(aux3, gLnk("R", "TDPolarizationEquivAxes", "vars/Time-Dependent.html#TDPolarizationEquivAxes"))
 insDoc(aux3, gLnk("R", "TDPolarizationWprime", "vars/Time-Dependent.html#TDPolarizationWprime"))
 aux2 = insFld(aux1, gFld("TD Output", "vars/Time-Dependent.html#Time-Dependent::TD_Output"))
+insDoc(aux2, gLnk("R", "MaxwellTDOutput", "vars/Time-Dependent.html#MaxwellTDOutput"))
 insDoc(aux2, gLnk("R", "TDExcitedStatesToProject", "vars/Time-Dependent.html#TDExcitedStatesToProject"))
 insDoc(aux2, gLnk("R", "TDFloquetDimension", "vars/Time-Dependent.html#TDFloquetDimension"))
 insDoc(aux2, gLnk("R", "TDFloquetFrequency", "vars/Time-Dependent.html#TDFloquetFrequency"))
@@ -688,6 +752,7 @@ insDoc(aux2, gLnk("R", "PropagationSpectrumDampMode", "vars/Utilities.html#Propa
 insDoc(aux2, gLnk("R", "PropagationSpectrumEndTime", "vars/Utilities.html#PropagationSpectrumEndTime"))
 insDoc(aux2, gLnk("R", "PropagationSpectrumEnergyStep", "vars/Utilities.html#PropagationSpectrumEnergyStep"))
 insDoc(aux2, gLnk("R", "PropagationSpectrumMaxEnergy", "vars/Utilities.html#PropagationSpectrumMaxEnergy"))
+insDoc(aux2, gLnk("R", "PropagationSpectrumMinEnergy", "vars/Utilities.html#PropagationSpectrumMinEnergy"))
 insDoc(aux2, gLnk("R", "PropagationSpectrumSigmaDiagonalization", "vars/Utilities.html#PropagationSpectrumSigmaDiagonalization"))
 insDoc(aux2, gLnk("R", "PropagationSpectrumStartTime", "vars/Utilities.html#PropagationSpectrumStartTime"))
 insDoc(aux2, gLnk("R", "PropagationSpectrumSymmetrizeSigma", "vars/Utilities.html#PropagationSpectrumSymmetrizeSigma"))
@@ -697,15 +762,32 @@ insDoc(aux2, gLnk("R", "SpectrumMethod", "vars/Utilities.html#SpectrumMethod"))
 insDoc(aux2, gLnk("R", "SpectrumSignalNoise", "vars/Utilities.html#SpectrumSignalNoise"))
 insDoc(aux2, gLnk("R", "TransientAbsorptionReference", "vars/Utilities.html#TransientAbsorptionReference"))
 aux2 = insFld(aux1, gFld("oct-test", "vars/Utilities.html#Utilities::oct-test"))
+insDoc(aux2, gLnk("R", "TestBatchOps", "vars/Utilities.html#TestBatchOps"))
 insDoc(aux2, gLnk("R", "TestHamiltonianApply", "vars/Utilities.html#TestHamiltonianApply"))
 insDoc(aux2, gLnk("R", "TestMaxBlockSize", "vars/Utilities.html#TestMaxBlockSize"))
 insDoc(aux2, gLnk("R", "TestMinBlockSize", "vars/Utilities.html#TestMinBlockSize"))
 insDoc(aux2, gLnk("R", "TestMode", "vars/Utilities.html#TestMode"))
 insDoc(aux2, gLnk("R", "TestRepetitions", "vars/Utilities.html#TestRepetitions"))
 insDoc(aux2, gLnk("R", "TestType", "vars/Utilities.html#TestType"))
+aux2 = insFld(aux1, gFld("oct-unfold", "vars/Utilities.html#Utilities::oct-unfold"))
+insDoc(aux2, gLnk("R", "UnfoldEnergyStep", "vars/Utilities.html#UnfoldEnergyStep"))
+insDoc(aux2, gLnk("R", "UnfoldKPointsPath", "vars/Utilities.html#UnfoldKPointsPath"))
+insDoc(aux2, gLnk("R", "UnfoldLatticeParameters", "vars/Utilities.html#UnfoldLatticeParameters"))
+insDoc(aux2, gLnk("R", "UnfoldLatticeVectors", "vars/Utilities.html#UnfoldLatticeVectors"))
+insDoc(aux2, gLnk("R", "UnfoldMaxEnergy", "vars/Utilities.html#UnfoldMaxEnergy"))
+insDoc(aux2, gLnk("R", "UnfoldMinEnergy", "vars/Utilities.html#UnfoldMinEnergy"))
+insDoc(aux2, gLnk("R", "UnfoldMode", "vars/Utilities.html#UnfoldMode"))
 aux2 = insFld(aux1, gFld("oct-vibrational_spectrum", "vars/Utilities.html#Utilities::oct-vibrational_spectrum"))
 insDoc(aux2, gLnk("R", "VibrationalSpectrumTime", "vars/Utilities.html#VibrationalSpectrumTime"))
 insDoc(aux2, gLnk("R", "VibrationalSpectrumTimeStepFactor", "vars/Utilities.html#VibrationalSpectrumTimeStepFactor"))
+aux2 = insFld(aux1, gFld("oct-wannier90", "vars/Utilities.html#Utilities::oct-wannier90"))
+insDoc(aux2, gLnk("R", "SCDMmu", "vars/Utilities.html#SCDMmu"))
+insDoc(aux2, gLnk("R", "SCDMsigma", "vars/Utilities.html#SCDMsigma"))
+insDoc(aux2, gLnk("R", "Wannier90Files", "vars/Utilities.html#Wannier90Files"))
+insDoc(aux2, gLnk("R", "Wannier90Mode", "vars/Utilities.html#Wannier90Mode"))
+insDoc(aux2, gLnk("R", "Wannier90Prefix", "vars/Utilities.html#Wannier90Prefix"))
+insDoc(aux2, gLnk("R", "Wannier90UseSCDM", "vars/Utilities.html#Wannier90UseSCDM"))
+insDoc(aux2, gLnk("R", "Wannier90UseTD", "vars/Utilities.html#Wannier90UseTD"))
 aux2 = insFld(aux1, gFld("oct-xyz-anim", "vars/Utilities.html#Utilities::oct-xyz-anim"))
 insDoc(aux2, gLnk("R", "AnimationMultiFiles", "vars/Utilities.html#AnimationMultiFiles"))
 insDoc(aux2, gLnk("R", "AnimationSampling", "vars/Utilities.html#AnimationSampling"))
