@@ -25,6 +25,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
+#include <fortran_types.h>
 
 #include "string_f.h" /* fortran <-> c string compatibility issues */
 
@@ -275,24 +276,27 @@ void FC_FUNC_(varinfo_getopt, VARINFO_GETOPT)
 
 
 /* --------------------------------------------------------- */
+
 void FC_FUNC_(varinfo_opt_getinfo, VARINFO_OPT_GETINFO)
-  (const opt_type **opt, char **name, int *value, char **desc)
+  (const opt_type **opt, char **name, fint8 *value, char **desc)
 {
   if(opt == NULL){
     *name = NULL; *desc = NULL;
     *value = 0;
-  }else{
+  } else {
     *name = (*opt)->name;
     *desc = (*opt)->desc;
     if((*opt)->value){
       if(strncmp("bit", (*opt)->value, 3) == 0){
-	*value = (1<<atoi((*opt)->value + 4));
+	*value = ((int64_t) 1)<<strtoll((*opt)->value + 4, NULL, 10);
       } else {
-	*value = atoi((*opt)->value);
+	*value = strtoll((*opt)->value, NULL, 10);
       }
-    }
-    else
+
+    } else {
       *value = 0;
+    }
+    
   }
 }
 
