@@ -31,11 +31,13 @@
 #define VEC_TYPE __m512d
 #define VEC_LD(addr) _mm512_load_pd(addr)
 #define VEC_LDU(addr) _mm512_loadu_pd(addr)
-#define VEC_ST(addr, vec)  _mm512_store_pd(addr, vec)
+#define VEC_ST(addr, vec)  _mm512_stream_pd(addr, vec)
 #define VEC_STU(addr, vec)  _mm512_storeu_pd(addr, vec)
 #define VEC_FMA(aa, bb, cc) _mm512_fmadd_pd(aa, bb, cc)
 #define VEC_SCAL(aa) _mm512_set1_pd(aa)
 #define VEC_ZERO _mm512_setzero_pd()
+#include <emmintrin.h>
+#define FENCE _mm_mfence()
 
 #define DEPTH 16
 
@@ -48,7 +50,7 @@
 #define VEC_TYPE __m256d
 #define VEC_LD(addr) _mm256_load_pd(addr)
 #define VEC_LDU(addr) _mm256_loadu_pd(addr)
-#define VEC_ST(addr, vec)  _mm256_store_pd(addr, vec)
+#define VEC_ST(addr, vec)  _mm256_stream_pd(addr, vec)
 #define VEC_STU(addr, vec)  _mm256_storeu_pd(addr, vec)
 #ifdef HAVE_FMA3
 #define VEC_FMA(aa, bb, cc) _mm256_fmadd_pd(aa, bb, cc)
@@ -59,6 +61,8 @@
 #endif
 #define VEC_SCAL(aa) _mm256_set1_pd(aa)
 #define VEC_ZERO _mm256_setzero_pd()
+#include <emmintrin.h>
+#define FENCE _mm_mfence()
 
 #define DEPTH 16
 #endif
@@ -72,7 +76,7 @@
 #define VEC_TYPE __m128d
 #define VEC_LD(addr) _mm_load_pd(addr)
 #define VEC_LDU(addr) _mm_loadu_pd(addr)
-#define VEC_ST(addr, vec)  _mm_store_pd(addr, vec)
+#define VEC_ST(addr, vec)  _mm_stream_pd(addr, vec)
 #define VEC_STU(addr, vec)  _mm_storeu_pd(addr, vec)
 #ifdef HAVE_FMA3
 #define VEC_FMA(aa, bb, cc) _mm_fmadd_pd(aa, bb, cc)
@@ -83,6 +87,7 @@
 #endif
 #define VEC_SCAL(aa) _mm_set1_pd(aa)
 #define VEC_ZERO _mm_setzero_pd()
+#define FENCE _mm_mfence()
 
 #define DEPTH 16
 #endif
