@@ -20,7 +20,6 @@
 
 #include <config.h>
 
-#if defined(HAVE_NFFT) 
 
 #include <stdio.h>
 #include <math.h>
@@ -28,80 +27,82 @@
 #include <string.h>
 #include <complex.h>
 
+#ifdef HAVE_NFFT
 #include "nfft3util.h"
 #include "nfft3.h"
-
-
+#else
+typedef int nfft_plan;
+#endif
 
 // NFFT FUNCTIONS
 void FC_FUNC(oct_nfft_init_1d,OCT_NFFT_INIT_1D)
-   (nfft_plan *plan, int *N1, int *M)
-{
-    nfft_init_1d(plan, *N1, *M);  
+   (nfft_plan *plan, int *N1, int *M){
+#ifdef HAVE_NFFT
+    nfft_init_1d(plan, *N1, *M);
+#endif
 }
 
 void FC_FUNC(oct_nfft_init_2d,OCT_NFFT_INIT_2D)
-   (nfft_plan *plan, int *N1, int *N2, int *M)
-{
-    nfft_init_2d(plan, *N1, *N2, *M);  
+   (nfft_plan *plan, int *N1, int *N2, int *M){
+#ifdef HAVE_NFFT
+    nfft_init_2d(plan, *N1, *N2, *M);
+#endif
 }
 
 void FC_FUNC(oct_nfft_init_3d,OCT_NFFT_INIT_3D)
-   (nfft_plan *plan, int *N1, int *N2, int *N3, int *M)
-{
-    nfft_init_3d(plan, *N1, *N2, *N3, *M);  
+   (nfft_plan *plan, int *N1, int *N2, int *N3, int *M){
+#ifdef HAVE_NFFT
+    nfft_init_3d(plan, *N1, *N2, *N3, *M);
+#endif
 }
 
 void FC_FUNC(oct_nfft_init_guru,OCT_NFFT_INIT_GURU) 
-  (nfft_plan *ths, int *d, int *N, int *M, int *n, int *m, unsigned *nfft_flags, unsigned *fftw_flags)
-{
+  (nfft_plan *ths, int *d, int *N, int *M, int *n, int *m, unsigned *nfft_flags, unsigned *fftw_flags){
+#ifdef HAVE_NFFT
   nfft_init_guru (ths, *d, N, *M, n, *m, *nfft_flags, *fftw_flags);
+#endif
 }
 
-void 	FC_FUNC(oct_nfft_check, OCT_NFFT_CHECK) 
-  (nfft_plan *ths)
-{
+void 	FC_FUNC(oct_nfft_check, OCT_NFFT_CHECK)(nfft_plan *ths){
+#ifdef HAVE_NFFT
   nfft_check (ths);
+#endif
 }
 
-void 	FC_FUNC(oct_nfft_finalize,OCT_NFFT_FINALIZE) 
-  (nfft_plan *ths)	
-{
+void 	FC_FUNC(oct_nfft_finalize,OCT_NFFT_FINALIZE)(nfft_plan *ths){
+#ifdef HAVE_NFFT
   nfft_finalize (ths);
+#endif
 }
 
-void 	FC_FUNC(oct_nfft_trafo,OCT_NFFT_TRAFO)
-   (nfft_plan *ths)
-{
+void 	FC_FUNC(oct_nfft_trafo,OCT_NFFT_TRAFO)(nfft_plan *ths){
+#ifdef HAVE_NFFT
   nfft_trafo (ths);
+#endif
 }  
   
-void 	FC_FUNC(oct_nfft_adjoint,OCT_NFFT_ADJOINT)
-   (nfft_plan *ths)
-{
+void 	FC_FUNC(oct_nfft_adjoint,OCT_NFFT_ADJOINT)(nfft_plan *ths){
+#ifdef HAVE_NFFT
   nfft_adjoint (ths);
+#endif
 }
   
-void FC_FUNC(oct_nfft_precompute_one_psi_1d, OCT_NFFT_PRECOMPUTE_ONE_PSI_1D)
-     (nfft_plan *plan, int *m, double *X1)
-{
+void FC_FUNC(oct_nfft_precompute_one_psi_1d, OCT_NFFT_PRECOMPUTE_ONE_PSI_1D)(nfft_plan *plan, int *m, double *X1){
 
+#ifdef HAVE_NFFT
    int ii;
    int M = *m;
  
-   for (ii=0;ii< M;ii++){
-     plan->x[ii] =  X1[ii];
-   }
+   for (ii=0;ii< M;ii++) plan->x[ii] =  X1[ii];
   
-   if(plan->nfft_flags & PRE_ONE_PSI)
-     nfft_precompute_one_psi(plan);
- 
+   if(plan->nfft_flags & PRE_ONE_PSI) nfft_precompute_one_psi(plan);
+#endif 
 }
 
-void FC_FUNC(oct_nfft_precompute_one_psi_2d, OCT_NFFT_PRECOMPUTE_ONE_PSI_2D)
-     (nfft_plan *plan, int *M, double* X1, double* X2)
-{
-   int ii;
+void FC_FUNC(oct_nfft_precompute_one_psi_2d, OCT_NFFT_PRECOMPUTE_ONE_PSI_2D)(nfft_plan *plan, int *M, double* X1, double* X2){
+
+#ifdef HAVE_NFFT
+	int ii;
    int jj;
 
    for (ii=0; ii< M[0]; ii++){
@@ -112,13 +113,13 @@ void FC_FUNC(oct_nfft_precompute_one_psi_2d, OCT_NFFT_PRECOMPUTE_ONE_PSI_2D)
     }
 
  
-   if(plan->nfft_flags & PRE_ONE_PSI)
-     nfft_precompute_one_psi(plan);
+   if(plan->nfft_flags & PRE_ONE_PSI)nfft_precompute_one_psi(plan);
+#endif
 }
 
 void FC_FUNC(oct_nfft_precompute_one_psi_3d, OCT_NFFT_PRECOMPUTE_ONE_PSI_3D)
-     (nfft_plan *plan, int *M, double* X1, double* X2, double* X3)
-{
+     (nfft_plan *plan, int *M, double* X1, double* X2, double* X3){
+#ifdef HAVE_NFFT
    int ii,jj,kk;
 
    for (ii=0;ii< M[0];ii++){
@@ -131,8 +132,8 @@ void FC_FUNC(oct_nfft_precompute_one_psi_3d, OCT_NFFT_PRECOMPUTE_ONE_PSI_3D)
      }
    }
   
-   if(plan->nfft_flags & PRE_ONE_PSI)
-     nfft_precompute_one_psi(plan);
+   if(plan->nfft_flags & PRE_ONE_PSI) nfft_precompute_one_psi(plan);
+#endif
 }
 
 // Type dependent functions 
@@ -140,9 +141,9 @@ void FC_FUNC(oct_nfft_precompute_one_psi_3d, OCT_NFFT_PRECOMPUTE_ONE_PSI_3D)
 
 // ********** COMPLEX ************
 void FC_FUNC(zoct_set_f, ZOCT_SET_F)
-    (nfft_plan *plan, int *M, int *DIM, double complex *VAL, int *IX, int *IY, int *IZ)
-{
+    (nfft_plan *plan, int *M, int *DIM, double complex *VAL, int *IX, int *IY, int *IZ){
 
+#ifdef HAVE_NFFT
   int dim = *DIM;
   int ix = *IX;
   int iy = *IY;
@@ -160,13 +161,13 @@ void FC_FUNC(zoct_set_f, ZOCT_SET_F)
        plan->f[(ix-1)*M[1]*M[2] + (iy-1)*M[2] + (iz-1)] = val;
      break;
      }
-
+#endif
 }
 
 void FC_FUNC(zoct_get_f, ZOCT_GET_F)
-    (nfft_plan *plan, int *M, int *DIM, double complex *val, int *IX, int *IY, int *IZ)
-{
+    (nfft_plan *plan, int *M, int *DIM, double complex *val, int *IX, int *IY, int *IZ){
 
+#ifdef HAVE_NFFT
   int dim = *DIM;
   int ix = *IX;
   int iy = *IY;
@@ -184,13 +185,14 @@ void FC_FUNC(zoct_get_f, ZOCT_GET_F)
        *val = plan->f[(ix-1)*M[1]*M[2] + (iy-1)*M[2] + (iz-1)];
      break;
    }
-
+#endif
 }
 
 
 void FC_FUNC(zoct_set_f_hat, ZOCT_SET_F_HAT)
-    (nfft_plan *plan, int *DIM, double complex *VAL, int *IX, int *IY, int *IZ)
-{
+    (nfft_plan *plan, int *DIM, double complex *VAL, int *IX, int *IY, int *IZ){
+
+#ifdef HAVE_NFFT
   int dim = *DIM;
   int ix = *IX;
   int iy = *IY;
@@ -208,12 +210,13 @@ void FC_FUNC(zoct_set_f_hat, ZOCT_SET_F_HAT)
        plan->f_hat[(ix-1)*plan->N[1]*plan->N[2] + (iy-1)*plan->N[2] + (iz-1)] = val;
      break;
    }
-
+#endif
 }
 
 void FC_FUNC(zoct_get_f_hat, ZOCT_GET_F_HAT)
-    (nfft_plan *plan, int *DIM, double complex *val, int *IX, int *IY, int *IZ)
-{
+    (nfft_plan *plan, int *DIM, double complex *val, int *IX, int *IY, int *IZ){
+
+#ifdef HAVE_NFFT
   int dim = *DIM;
   int ix = *IX;
   int iy = *IY;
@@ -231,14 +234,14 @@ void FC_FUNC(zoct_get_f_hat, ZOCT_GET_F_HAT)
        *val = plan->f_hat[(ix-1)*plan->N[1]*plan->N[2] + (iy-1)*plan->N[2] + (iz-1)];
      break;
    }
-
+#endif
 }
 
 // ********** DOUBLE ************
 void FC_FUNC(doct_set_f, DOCT_SET_F)
-    (nfft_plan *plan, int *M, int *DIM, double *VAL, int *IX, int *IY, int *IZ)
-{
+    (nfft_plan *plan, int *M, int *DIM, double *VAL, int *IX, int *IY, int *IZ){
 
+#ifdef HAVE_NFFT
   int dim = *DIM;
   int ix = *IX;
   int iy = *IY;
@@ -257,13 +260,13 @@ void FC_FUNC(doct_set_f, DOCT_SET_F)
        plan->f[(ix-1)*M[1]*M[2] + (iy-1)*M[2] + (iz-1)] = val;
      break;
    }
-
+#endif
 }
 
 void FC_FUNC(doct_get_f, DOCT_GET_F)
-    (nfft_plan *plan, int *M, int *DIM, double *val, int *IX, int *IY, int *IZ)
-{
+    (nfft_plan *plan, int *M, int *DIM, double *val, int *IX, int *IY, int *IZ){
 
+#ifdef HAVE_NFFT
   int dim = *DIM;
   int ix = *IX;
   int iy = *IY;
@@ -281,13 +284,14 @@ void FC_FUNC(doct_get_f, DOCT_GET_F)
        *val = plan->f[(ix-1)*M[1]*M[2] + (iy-1)*M[2] + (iz-1)];
      break;
    }
-
+#endif
 }
 
 
 void FC_FUNC(doct_set_f_hat, DOCT_SET_F_HAT)
-    (nfft_plan *plan, int *DIM, double *VAL, int *IX, int *IY, int *IZ)
-{
+    (nfft_plan *plan, int *DIM, double *VAL, int *IX, int *IY, int *IZ){
+
+#ifdef HAVE_NFFT
   int dim = *DIM;
   int ix = *IX;
   int iy = *IY;
@@ -305,12 +309,13 @@ void FC_FUNC(doct_set_f_hat, DOCT_SET_F_HAT)
        plan->f_hat[(ix-1)*plan->N[1]*plan->N[2] + (iy-1)*plan->N[2] + (iz-1)] = val;
      break;
    }
-
+#endif
 }
 
 void FC_FUNC(doct_get_f_hat, DOCT_GET_F_HAT)
-    (nfft_plan *plan, int *DIM, double *val, int *IX, int *IY, int *IZ)
-{
+    (nfft_plan *plan, int *DIM, double *val, int *IX, int *IY, int *IZ){
+	
+#ifdef HAVE_NFFT
   int dim = *DIM;
   int ix = *IX;
   int iy = *IY;
@@ -328,7 +333,7 @@ void FC_FUNC(doct_get_f_hat, DOCT_GET_F_HAT)
        *val = plan->f_hat[(ix-1)*plan->N[1]*plan->N[2] + (iy-1)*plan->N[2] + (iz-1)];
      break;
    }
-
+#endif
 }
 
-#endif 
+
